<%--
  -- Reciprocal Net project
  -- /admin/editlab.jsp
  --
  -- 22-July-2002: hclin wrote first draft
  -- 09-Aug-2002: hclin fixed bug #295
  -- 14-Aug-2002: hclin fixed bug #355
  -- 21-Aug-2002: eisiorho removed TODO, task #373
  -- 13-Sep-2002: jobollin corrected title capitalization per task 332
  -- 17-Oct-2002: eisiorho changed UI of action deleting a Lab.
  -- 15-Nov-2002: eisiorho fixed bug #600
  --%>

<%--
    The session="true" and isThreadSafe="true" attributes of the page
    directive are the default values; they simply serve as reminders,
    and as place holders should the defaults need to be overriden.  A
    specific error page could also be specified here; because it is not,
    any specified in this application's web.xml file will be used as a default
--%>
<%@page session="true" isThreadSafe="true"
        info="Site Administration - Edit Lab"
        import="org.recipnet.site.wrapper.HtmlHelper"
        import="org.recipnet.site.container.LabInfo"
        import="org.recipnet.site.container.UserInfo"
        import="org.recipnet.site.container.ProviderInfo"
        import="org.recipnet.site.container.SiteInfo"
        import="java.util.List"
        import="java.util.Iterator" %>
<%@include file="/WEB-INF/common.inc" %>
<%-- authController, pageHelper, and replController now available --%>

<%
    /*
     * This page is accessible only to site and lab administrators.
     * Request unauthenticated users to authenticate:
     */
    if ( !authController.checkUserAuthenticationStatus() ) {
        request.setAttribute("reason", authController.AUTHENTICATION_REQUIRED);
%>
        <jsp:forward page="/login.jsp" />
<%
    }
    /* Check if the requested labId is valid */
    int labId = LabInfo.INVALID_LAB_ID;
    String labIdStr = request.getParameter("labId");
    if (labIdStr == null) {
       ((HttpServletResponse) response).sendError(
               HttpServletResponse.SC_BAD_REQUEST);
    } else {
        try {
            labId = Integer.parseInt(labIdStr);
        } catch (NumberFormatException nfe) {
            ((HttpServletResponse) response).sendError(
                    HttpServletResponse.SC_BAD_REQUEST);
        }
    }

    /*
     * Make certain that an authenticated user is either a lab or a site
     * admin and can edit this requested lab.
     */
    if (!authController.canAdministerLab(labId)) {
        request.setAttribute("reason", authController.INSUFFICIENT_ACCESS);
%>
        <jsp:forward page="/login.jsp" />
<%
    }

    /*
     * If control reaches here then the requested labId is valid and the user is
     * authorized to edit the lab specified in his request.
     */

    LabInfo labInfo = pageHelper.getLabInfo(labId);
    SiteInfo siteInfo = pageHelper.getSiteInfo(labInfo.homeSiteId);
    List userInfoList = pageHelper.getUsersForLab(labId);
    Iterator iterator = userInfoList.iterator();
    UserInfo userInfo;
    boolean posted = false;
    String errorMsg = "";
    String method = ((HttpServletRequest) request).getMethod();
    if ("POST".equals(method)) {
        posted = true;
        try {
            labInfo.name = request.getParameter("name");
            labInfo.defaultCopyrightNotice = request.getParameter(
                    "defaultCopyrightNotice");
            labInfo.shortName = request.getParameter("shortName");
            labInfo.homeUrl = request.getParameter("homeUrl");
            labInfo.directoryName = request.getParameter("directoryName");
            if (labInfo.name == null || labInfo.name.equals("")) {
                /* Validation Error -- drop through */
                errorMsg = "Lab name can not be empty.";
            } else {
                if (request.getParameter("isActive") != null
                    && request.getParameter("isActive").equals("on")) {
                    labInfo.isActive = Boolean.getBoolean("false");
                }
                pageHelper.writeUpdatedLabInfo(labInfo);
                ((HttpServletResponse) response).sendRedirect("managelabs.jsp");
            }
        } catch (NumberFormatException nfe) {
            /* Validation Error -- drop through as if this was a GET request */
        }
    }
    /*
     * If controls reaches here then we have either a POST request with a
     * validation error or a GET request.
     */
%>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
          "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
    <title>Reciprocal Net - <%=getServletInfo()%></title>
    <link href="../recipnet.css" rel="stylesheet" type="text/css" />
  </head>
  <body>
    <jsp:include page="/header.jsp">
        <jsp:param name="pageTitle" value="<%=getServletInfo() %>" />
    </jsp:include>
    <br />
<%  if (posted)  { %>
    <p class="errorMessage">Validation Error -- please check your entries and
                            resubmit. (Lab name can not be empty.)</p>
<%  }
    if (labInfo.isActive == true) {
%>
    <form method="POST">
    <table class="adminFormTable"  border="0" cellspacing="0">
      <tr>
        <th class="twoColumnLeft">Lab ID:</th>
        <td class="twoColumnRight"><%=labInfo.id%></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Home Site(ID):</th>
        <td class="twoColumnRight"><%=siteInfo.name%> (<%= labInfo.homeSiteId%>)</td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Lab Name:</th>
        <td class="twoColumnRight">
          <input name="name" type="text" size="64" maxlength="64"
                 value="<%= HtmlHelper.nullToBlank(labInfo.name)%>"></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Lab Short Name:</th>
        <td class="twoColumnRight">
          <input name="shortName" type="text" size="64" maxlength="20"
                 value="<%= HtmlHelper.nullToBlank(labInfo.shortName)%>"></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Lab Home URL:</th>
        <td class="twoColumnRight">
          <input name="homeUrl" type="text" size="64"  maxlength="128"
                 value="<%= HtmlHelper.nullToBlank(labInfo.homeUrl)%>"></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Lab Directory Name:</th>
        <td class="twoColumnRight">
          <input name="directoryName" type="text" size="64"  maxlength="128"
                value="<%=HtmlHelper.nullToBlank(labInfo.directoryName)%>"></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Default Copyright Notice:</th>
        <td class="twoColumnRight">
           <textarea name="defaultCopyrightNotice" rows="10" cols="50"><%=HtmlHelper.nullToBlank(labInfo.defaultCopyrightNotice).trim()%></textarea>
        </td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Submit your changes: </th>
        <td class="twoColumnRight"><input type="submit" value="Submit"></td>
      </tr>
    </table>
  </form><br />
<%      if (!userInfoList.isEmpty()) {%>
    <p class="headerFont1">User accounts associated with this lab:</p>
    <table class="adminFormTable" border="0" cellspacing="0">
      <tr class="headerColor">
        <th class="threeColumnLeft">User full name</th>
        <th class="threeColumnMiddle">Username</th>
        <th>&nbsp;</th>
      </tr>
<%
            boolean color = true;
            while (iterator.hasNext()) {
                userInfo = (UserInfo)iterator.next();
                if (!userInfo.isActive) {
%>
      <tr class="rowColor<%=color%>">
        <td class="threeColumnLeft"><%=userInfo.fullName%></td>
        <td class="threeColumnMiddle"><%=userInfo.username%> (deactivated)</td>
        <td class="threeColumnLeft">
          <a href="edituser.jsp?labId=<%=labId%>&providerId=<%=
                    ProviderInfo.INVALID_PROVIDER_ID%>&userId=<%=userInfo.id%>">
            View this user's information
          </a>
        </td>
      </tr>
<%              } else {  %>
      <tr class="rowColor<%=color%>">
        <td class="threeColumnLeft"><%=userInfo.fullName%></td>
        <td class="threeColumnMiddle"><%=userInfo.username%></td>
        <td class="threeColumnLeft">
          <a href="edituser.jsp?labId=<%=labId%>&providerId=<%=
                    ProviderInfo.INVALID_PROVIDER_ID%>&userId=<%=userInfo.id%>">
            Edit this user
          </a>
        </td>
      </tr>
<%
                }
                color = !color;
            }
%>
      <tr class="rowColor<%=color%>">
        <td class="threeColumnLeft">
          <a href="edituser.jsp?userId=<%=UserInfo.INVALID_USER_ID%>&labId=<%=
                    labId%>&providerId=<%=ProviderInfo.INVALID_PROVIDER_ID%>">
             Add a new user</a>
        </td>
        <td>&nbsp;</td>
        <td>&nbsp;</td>
      </tr>
    </table>

<%      } else { %>
    <p class="headerFont1">No user account associated with this lab.</p>
    <a href="edituser.jsp?userId=<%=UserInfo.INVALID_USER_ID%>&labId=<%=
                    labId%>&providerId=<%=ProviderInfo.INVALID_PROVIDER_ID%>">
    Add a new user</a>
<%
        }
    } else {
%>
    <table class="adminFormTable">
      <tr>
        <th class="twoColumnLeft">Lab ID:</th>
        <td class="twoColumnRight"><%=labInfo.id%></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Home Site (ID):</th>
        <td class="twoColumnRight"><%=siteInfo.name%> (<%= labInfo.homeSiteId%>)</td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Lab Name:</th>
        <td class="twoColumnRight"><%= HtmlHelper.nullToBlank(
                                               labInfo.name)%></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Lab Short Name:</th>
        <td class="twoColumnRight"><%= HtmlHelper.nullToBlank(
                                               labInfo.shortName)%></td>
      </tr>
      <tr border="1">
        <th class="twoColumnLeft">Lab Home URL:</th>
        <td class="twoColumnRight"><%= HtmlHelper.nullToBlank(
                                               labInfo.homeUrl)%></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Lab Directory Name:</th>
        <td class="twoColumnRight"><%=HtmlHelper.nullToBlank(
                                              labInfo.directoryName)%></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Default Copyright Notice:</th>
        <td class="twoColumnRight"><p><%=HtmlHelper.nullToBlank(
                                      labInfo.defaultCopyrightNotice)%></p></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Is Active:</th>
        <td class="twoColumnRight">No.</td>
      </tr>
    </table>
<%  } %>
    <jsp:include page="/footer.jsp" />
  </body>
</html>
