<%--
  -- Reciprocal Net project
  -- /admin/editprovider.jsp
  --
  -- 22-July-2002: hclin wrote first draft
  -- 09-Aug-2002: hclin fixed bug #295
  -- 14-Aug-2002: hclin fixed bug #354
  -- 21-Aug-2002: eisiorho removed TODO, task #373
  -- 13-Sep-2002: jobollin corrected title capitalization per task 332
  -- 17-Oct-2002: eisiorho changed UI of action deleting a Provider Site.
  -- 06-Dec-2002: eisiorho fixed bug #636
  -- 06-Dec-2002: eisiorho added code to check for empty text boxes on form post
  --%>
<%--
    The session="true" and isThreadSafe="true" attributes of the page
    directive are the default values; they simply serve as reminders, and as
    place holders should the defaults need to be overriden.  A specific error
    page could also be specified here; because it is not, any specified in
    this application's web.xml file will be used as a default.
--%>
<%@page session="true" isThreadSafe="true"
        info="Site Administration - Edit Provider"
        import="org.recipnet.site.wrapper.HtmlHelper"
        import="org.recipnet.site.container.ProviderInfo"
        import="org.recipnet.site.container.UserInfo"
        import="org.recipnet.site.container.LabInfo"
        import="java.util.List"
        import="java.util.Iterator" %>
<%@include file="/WEB-INF/common.inc" %>
<%-- authController, pageHelper, and replController now available --%>

<%
    /*
     * This page is accessible only to site and lab administrators.
     * Request unauthenticated users to authenticate:
     */
    if ( !authController.checkUserAuthenticationStatus() ) {
        request.setAttribute("reason", authController.AUTHENTICATION_REQUIRED);
%>
        <jsp:forward page="/login.jsp" />
<%
    }

    /* Check if the labId and the providerId are valid */
    int labId = LabInfo.INVALID_LAB_ID;
    String labIdStr = request.getParameter("labId");
    int providerId = ProviderInfo.INVALID_PROVIDER_ID;
    String providerIdStr = request.getParameter("providerId");
    if (labIdStr == null || providerIdStr == null) {
       ((HttpServletResponse) response).sendError(
               HttpServletResponse.SC_BAD_REQUEST);
       return;
    } else {
        try {
            labId = Integer.parseInt(labIdStr);
            providerId = Integer.parseInt(providerIdStr);
        } catch (NumberFormatException nfe) {
            ((HttpServletResponse) response).sendError(
                    HttpServletResponse.SC_BAD_REQUEST);
          return;
        }
    }

    /*
     * Make certain that an authenticated user can edit this sepecified provider
     */
    if (!authController.canAdministerLab(labId)) {
        request.setAttribute("reason", authController.INSUFFICIENT_ACCESS);
%>
        <jsp:forward page="/login.jsp" />
<%
    }

    /*
     * If control reaches here then the requested labId is valid and the user is
     * authorized to edit the provider specified in his request.
     */
    ProviderInfo providerInfo = pageHelper.getProviderInfo(providerId);
    if (providerId == ProviderInfo.INVALID_PROVIDER_ID) {
        providerInfo.isActive = true;
        providerInfo.labId= labId;
    }
    LabInfo labInfo = pageHelper.getLabInfo(labId);
    boolean posted = false;
    boolean confirmDeletion = false;
    String method = ((HttpServletRequest) request).getMethod();
    String errorMsg ="";
    if ("POST".equals(method)) {
        posted = true;
        try {

            String name =  request.getParameter("name");


            if (name != null && !"".equals(name)) {
                providerInfo.name =  name;
            } else {
                /* Validation Error -- drop through as if this was a GET request */
                errorMsg = "Provider name can not be empty.";
            }
            if (request.getParameter("comments") == null)	{
            	providerInfo.comments = null;
        	} else {
            	String comments = request.getParameter("comments").trim();
            	providerInfo.comments = comments.length() > 0 ? comments : null;
			}
            if (request.getParameter("headContact") == null)	{
            	providerInfo.headContact = null;
        	} else {
            	String headContact = request.getParameter("headContact").trim();
            	providerInfo.headContact = headContact.length() > 0 ? headContact : null;
			}

            if (request.getParameter("isActive") != null &&
                "Deactivate".equals(request.getParameter("isActive"))){
                errorMsg = "Deleting";
                confirmDeletion = true;
                if (request.getParameter("delete") != null &&
                      "Yes, Deactivate".equals(request.getParameter("delete"))) {
                    providerInfo.isActive = false;
                    errorMsg = "";
                } else if (request.getParameter("delete") != null &&
                           "Cancel".equals(request.getParameter("delete"))) {
                    errorMsg = "";
                }
            }
            if ("".equals(errorMsg)) {
                pageHelper.writeUpdatedProviderInfo(providerInfo);
                String url = "manageproviders.jsp?labId=" + labId;
                ((HttpServletResponse) response).sendRedirect(url);
            }
        } catch (NumberFormatException nfe) {
            /* Validation Error -- drop through as if this was a GET request */
        }
    }

    /*
     * If controls reaches here then we have either a POST request with a
     * validation error or a GET request.
     */
%>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
          "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
    <title>Reciprocal Net - <%=getServletInfo() %></title>
    <link href="../recipnet.css" rel="stylesheet" type="text/css" />
  </head>
  <body>
    <jsp:include page="/header.jsp">
        <jsp:param name="pageTitle" value="<%=getServletInfo() %>" />
    </jsp:include>
    <br />
<% if (confirmDeletion) { %>
    <center>
      <h2>
        <p class="errorMessage">
          You are about to deactivate provider <font color="blue"><%= providerInfo.name %></font>,
          and all user accounts associated. This will prevent new samples from
          being submitted under this provider, but will not affect existing
          samples. This action cannot be undone. Are you sure you want to
          procede?
        </p>
      </h2>
      <form method="POST" name="del" id="del">
        <input type="hidden" name="isActive" id="isActive" value="Deactivate">
        <input type="submit" name="delete" id="delete" value="Cancel">
        <input type="submit" name="delete" id="delete" value="Yes, Deactivate">
      </form>
    </center>
<% } else {
       if (posted) { %>
    <p class="errorMessage">Validation Error -- please check your entries and resubmit. (<%=errorMsg%>)</p>
<%     }
       if (providerInfo.isActive == false) { %>
    <table class="adminFormTable">
      <tr>
        <th class="twoColumnLeft">Provider ID:</th>
        <td class="twoColumnRight"><%= providerInfo.id%></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Lab Name (ID):</th>
        <td  class="twoColumnRight"><%=labInfo.name%> (<%=providerInfo.labId%>)</td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Provider Name:</th>
        <td class="twoColumnRight"><%= HtmlHelper.nullToBlank(providerInfo.name)%>
        </td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Provider Head Contact:</th>
        <td class="twoColumnRight"><%= HtmlHelper.nullToBlank(providerInfo.headContact)%></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Comments:</th>
        <td class="twoColumnRight">
          <p><%= HtmlHelper.nullToBlank(providerInfo.comments)%></p>
        </td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Is Active?</th>
        <td class="twoColumnRight">No.</td>
      </tr>
    </table>
<%     } else if (providerInfo.id != ProviderInfo.INVALID_PROVIDER_ID) { %>
    <form method="POST">
      <input type="hidden" name="providerId" value="<%=providerId%>">
      <input type="hidden" name="labId" value="<%=labId%>">
      <table class="adminFormTable">
        <tr>
          <th class="twoColumnLeft">Provider ID:</th>
          <td class="twoColumnRight"><%=providerInfo.id%></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Lab Name (ID):</th>
        <td  class="twoColumnRight"><%=labInfo.name%> (<%=providerInfo.labId%>)</td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Provider Name:</th>
        <td class="twoColumnRight">
          <input name="name" type="text" size="64" maxlength="64"
                 value="<%= HtmlHelper.nullToBlank(providerInfo.name)%>">
        </td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Provider Head Contact:</th>
        <td class="twoColumnRight">
          <input name="headContact" type="text" size="64" maxlength="64"
                 value="<%= HtmlHelper.nullToBlank(providerInfo.headContact).trim()%>">
        </td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Comments:</th>
        <td class="twoColumnRight">
          <textarea rows="10" cols="50" name="comments"><%= HtmlHelper.nullToBlank(providerInfo.comments).trim()%></textarea>
        </td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Submit your changes: </th>
        <td class="twoColumnRight"><input type="submit" value="Submit"></td>
      </tr>
      <tr>
        <td colspan="2"> <hr /> </td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Deactivate this provider:</th>
        <td class="twoColumnRight">
          <input type="submit" name="isActive" id="isActive" Value="Deactivate">
        </td>
      </tr>
    </table>
    </form><br />
<%
           List userInfoList = pageHelper.getUsersForProvider(providerId);
           Iterator iterator = userInfoList.iterator();
           UserInfo userInfo;
           if (!userInfoList.isEmpty()) {%>
    <p class="headerFont1">User accounts associated with this lab:</p>
    <table class="adminFormTable" border="0" cellspacing="0">
      <tr class="headerColor">
        <th class="threeColumnLeft">User full name</th>
        <th class="threeColumnMiddle">Username</th>
        <th>&nbsp;</th>
      </tr>
<%
               boolean color = true;
               while (iterator.hasNext()) {
                   userInfo = (UserInfo)iterator.next();
                   if (!userInfo.isActive) {
%>
      <tr class="rowColor<%=color%>">
        <td class="threeColumnLeft"><%=userInfo.fullName%></td>
        <td class="threeColumnMiddle"><%=userInfo.username%> (deactivated)</td>
        <td class="threeColumnLeft">
          <a href="edituser.jsp?userId=<%=userInfo.id%>&labId=<%=LabInfo.INVALID_LAB_ID%>&providerId=<%=providerId%>">
            View this user's information
          </a>
        </td>
      </tr>
<%                 } else {  %>
      <tr class="rowColor<%=color%>">
        <td class="threeColumnLeft"><%=userInfo.fullName%></td>
        <td class="threeColumnMiddle"><%=userInfo.username%></td>
        <td class="threeColumnLeft">
          <a href="edituser.jsp?labId=<%=LabInfo.INVALID_LAB_ID%>&providerId=<%=providerId%>&userId=<%=userInfo.id%>">
            Edit this user
          </a>
        </td>
      </tr>
<%
                   }
                   color = !color;
               }
%>
      <tr class="rowColor<%=color%>">
        <td colspan="3" class="threeColumnLeft">
          <a href="edituser.jsp?userId=<%=UserInfo.INVALID_USER_ID%>&labId=<%=LabInfo.INVALID_LAB_ID%>&providerId=<%=providerId%>">
             Add a new user</a>
        </td>
      </tr>
    </table>
<%         } else { %>
    <p class="headerFont1">No user account associated with this lab.</p>
    <a href="edituser.jsp?userId=<%=UserInfo.INVALID_USER_ID%>&labId=<%=LabInfo.INVALID_LAB_ID%>&providerId=<%=providerId%>">
    Add a new user</a>
<%
           }
       } else if (providerInfo.id == ProviderInfo.INVALID_PROVIDER_ID) { %>
    <form method="POST">
    <input type="hidden" name="providerId" value="<%=providerId%>">
    <input type="hidden" name="labId" value="<%=labId%>">
    <table class="adminFormTable">
      <tr>
        <th class="twoColumnLeft">Lab Name (ID):</th>
        <td  class="twoColumnRight"><%=labInfo.name%>(<%=labInfo.id%>)</td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Provider Name:</th>
        <td class="twoColumnRight"><input name="name" type="text" size="64" maxlength="64"
                                           value="<%= HtmlHelper.nullToBlank(request.getParameter("name"))%>"></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Provider Head Contact:</th>
        <td class="twoColumnRight"><input name="headContact" type="text" size="64" maxlength="64"
                                                 value="<%= HtmlHelper.nullToBlank(request.getParameter("headContact"))%>"></td>
      </tr>
      <tr>
        <th class="twoColumnLeft">Comments:</th>
        <td class="twoColumnRight">
          <textarea rows="10" cols="50" name="comments"><%=HtmlHelper.nullToBlank(request.getParameter("comments")).trim()%></textarea>
        </td>
      </tr>
      <tr>
        <td></td>
        <td class="twoColumnRight"><input type="submit" value="Submit"></td>
      </tr>
    </table>
    </form>
<%     }
   }
%>
    <jsp:include page="/footer.jsp" />
  </body>
</html>
