<%--
  -- Reciprocal Net project
  -- /admin/edituser.jsp
  --
  -- 22-Jul-2002: hclin wrote first draft
  -- 09-Aug-2002: hclin fixed bug #295
  -- 13-Aug-2002: ekoperda did UI refinement (bug #342)
  -- 13-Aug-2002: hclin fixed bug #353, #356
  -- 21-Aug-2002: eisiorho removed TODO, task #373
  -- 21-Aug-2002: eisiorho fixed bug #374, line 64
  -- 13-Sep-2002: jobollin corrected title capitalization per task 332
  -- 17-Sep-2002: ekoperda fixed bug #442
  -- 01-Oct-2002: eisiorho fixed bug #505, remove try, catch block
  -- 08-Oct-2002: eisiorho fixed bug #515, code is now cleaner
  -- 17-Oct-2002: eisiorho changed UI of action deleting an User.
  -- 13-Dec-2002: adharurk fixed bugs #635 and #648
  --%>
<%@page session="true" isThreadSafe="true"
        info="Site Administration - Edit User"
        import="org.recipnet.site.wrapper.HtmlHelper"
        import="org.recipnet.site.container.UserInfo"
        import="org.recipnet.site.container.LabInfo"
        import="org.recipnet.site.container.ProviderInfo"
        import="java.util.Date"
        import="java.util.List"
        import="java.util.Locale"
        import="java.text.DateFormat"
%>
<%@include file="/WEB-INF/common.inc" %>
<%

    /* Check if the labId, providerId and userId are valid */
    int labId = LabInfo.INVALID_LAB_ID;
    int providerId = ProviderInfo.INVALID_PROVIDER_ID;
    int userId = UserInfo.INVALID_USER_ID;
    String labIdStr = request.getParameter("labId");
    String providerIdStr = request.getParameter("providerId");
    String userIdStr = request.getParameter("userId");

    if (labIdStr == null || providerIdStr == null || userIdStr == null) {
       ((HttpServletResponse) response).sendError(
               HttpServletResponse.SC_BAD_REQUEST);
       return;
    } else {
        try {
            labId = Integer.parseInt(labIdStr);
            providerId = Integer.parseInt(providerIdStr);
            userId = Integer.parseInt(userIdStr);
        } catch (NumberFormatException nfe) {
            ((HttpServletResponse) response).sendError(
                    HttpServletResponse.SC_BAD_REQUEST);
          return;
        }
    }

    /*
     * This page is accessible only to site and lab administrators.
     * Request that unauthenticated users authenticate:
     */
    if ( !authController.checkUserAuthenticationStatus() ) {
        request.setAttribute("reason",
                             authController.AUTHENTICATION_REQUIRED); %>
        <jsp:forward page="/login.jsp" />
<%  }

    /*
     * See if the user is authorized to perform the action he's requested -
     * either he's attempting to edit an existing user or attempting to create
     * a new user.
     */
    boolean authorized;
    if (userId != UserInfo.INVALID_USER_ID) {
        // Attempting to edit an existing user
        authorized = authController.canEditUser(userId);
    } else {
        // Attempting to create a new user
        if (labId != LabInfo.INVALID_LAB_ID) {
            authorized = authController.canCreateLabUser(labId);
        } else {
            authorized = authController.canCreateProviderUser(providerId);
        }
    }
    if (!authorized) {
        request.setAttribute("reason",
                       	     authController.INSUFFICIENT_ACCESS); %>
        <jsp:forward page="/login.jsp" />
<%  }

    /*
     * If control reaches here then the requested labId, providerId and userId
     * are valid and the user is authorized to edit the user specified in his
     * request or create a new user.
     */
    boolean posted = false;
    boolean confirmDeletion = false;
    String method = ((HttpServletRequest) request).getMethod();
    UserInfo userInfo = pageHelper.getUserInfo(userId);
    if (userId == UserInfo.INVALID_USER_ID) userInfo.isActive=true;
    LabInfo labInfo;
    ProviderInfo providerInfo;
    int globalAccessLevel = 0;
    String errorMsg = "";
    DateFormat dateFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT,
	                                                       DateFormat.SHORT,
                                                           Locale.US);

    if ("POST".equals(method)) {
        posted = true;
        String resetPassword = request.getParameter("resetPassword");
        String username      = request.getParameter("username");
        String password      = request.getParameter("password");
        String fullName      = request.getParameter("fullName");
        String providerLabId = request.getParameter("providerLabId");
        globalAccessLevel = 0;
        /*
         * This page performs three main functions. The first is to create a
         * new user. The second is to change data about the user, whether
         * access level or password. The third is to deactivate the user from
         * this particular site.
         */
        if (request.getParameter("scientificUser") != null
             && request.getParameter("scientificUser").equals("on")) {
            globalAccessLevel += UserInfo.LAB_SCIENTIFIC_USER_ACCESS;
        }
        if (request.getParameter("labAdmin") != null
             && request.getParameter("labAdmin").equals("on")) {
            globalAccessLevel += UserInfo.LAB_ADMIN_ACCESS;
        }
        if (request.getParameter("siteAdmin") != null
             && request.getParameter("siteAdmin").equals("on")) {
            globalAccessLevel += UserInfo.SITE_ADMIN_ACCESS;
        }
        userInfo.globalAccessLevel = globalAccessLevel;
        if (request.getParameter("fullName") != null || "".equals(fullName)) {
            userInfo.fullName = fullName;
        }
        /* This checks whether or not to deactivate a user */
        if (request.getParameter("isActive") != null
            && request.getParameter("isActive").equals("Deactivate")) {
            errorMsg="Deleting";
            confirmDeletion = true;
            if (request.getParameter("delete") != null &&
                "Yes, Deactivate".equals(request.getParameter("delete"))) {
                userInfo.isActive = false;
                userInfo.inactiveDate = new Date();
                errorMsg="";
            } else if ("Cancel".equals(request.getParameter("delete"))) {
                errorMsg="";
            }
        } else if (resetPassword != null && resetPassword.equals("Submit")) {

            /*
             * First check if the user requests reset the password only.
             * Validation error - when password is not set properly. Then check
             * if username and password are valid. Logic is structured in such a
             * way that if and only if the user clicked on submit button to
             * change the password of an account, then the password fields will
             * be checked. Otherwise, it's just a regular 'submit' button.
             */
            String password1 = request.getParameter("password1");
            String password2 = request.getParameter("password2");

            if ( password1 == null || password2 == null
                || password1.equals("") || password2.equals("")
                || !password1.equals(password2)) {

                /* Validation Error -- drop through as if this was a GET request. */
                errorMsg = "Validation Error -- new passwords don't match";
            } else {

                /* This changes data about a specified user */
                userInfo.password = request.getParameter("password1");
                userInfo.setPassword(userInfo.password);
            }
        } else if (username == null || username.equals("") ||
                   password == null || password.equals("") ||
                   fullName == null || fullName.equals("")) {

            /* Validation Error -- drop through as if this was a GET request. */
            errorMsg = "Validation Error -- please check your entries and resubmit";
        } else {
            /* This adds a new user account to the site. */
            if (userInfo.id == UserInfo.INVALID_USER_ID) {
                if (labId != LabInfo.INVALID_LAB_ID){
                    userInfo.labId = labId;
                } else {
                    userInfo.providerId = providerId;
                }
                userInfo.username = username;
                userInfo.password = password;
                userInfo.setPassword(userInfo.password);
                userInfo.isActive = true;
                userInfo.creationDate = new Date();
            }
        }

        /* Redirect back to editlab.jsp or editprovider.jsp as appropriate */
		String url;
        if ("".equals(errorMsg)) {
            if (!"Cancel".equals(request.getParameter("delete"))){
                pageHelper.writeUpdatedUserInfo(userInfo);
            }
            if (userInfo.labId != LabInfo.INVALID_LAB_ID) {
                url = "editlab.jsp?labId=" + userInfo.labId;
            } else {
                providerInfo = pageHelper.getProviderInfo(userInfo.providerId);
                url = "editprovider.jsp?providerId=" + userInfo.providerId
                      + "&labId=" + providerInfo.labId;
            }
            ((HttpServletResponse) response).sendRedirect(url);
        }
    }

    /*
     * If controls reaches here then we have either a POST request with a
     * validation error or a GET request.
     */
%>                                                                                 

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
          "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
    <title>Reciprocal Net - <%=getServletInfo()%></title>
    <link href="../recipnet.css" rel="stylesheet" type="text/css" />
  </head>
  <body>
    <jsp:include page="/header.jsp">
        <jsp:param name="pageTitle" value="<%=getServletInfo() %>" />
    </jsp:include>
    <br />
<% if (confirmDeletion) { %>
  <center>
    <h2>
      <p class="errorMessage" >
        You are about to deactive the username "<font color="blue"><%= userInfo.username %></font>",
        for <font color="blue"><%= userInfo.fullName %></font>. This user will not be able to log in again.
        Are you sure you want to do this?
      </p>
    </h2>
    <form method="POST">
      <input type="hidden" name="isActive" id="isActive" value="Deactivate">
      <input type="submit" name="delete" id="delete" value="Cancel">
      <input type="submit" name="delete" id="delete" value="Yes, Deactivate">
    </form>
  </center>
<% } else { %>

<%     if (posted) { %>
      <p class="errorMessage">
        <%=errorMsg%>
      </p>
<%     }

       if (userInfo.isActive == false) {
           // Display a table that shows the deactivated user's field values %>

      <table class="adminFormTable" >
        <tr>
          <th class="twoColumnLeft">User ID:</th>
          <td class="twoColumnRight"><%= userInfo.id%></td>
        </tr>
        <tr>
          <th class="twoColumnLeft">User Name:</th>
          <td class="twoColumnRight">
            <%=HtmlHelper.nullToBlank(userInfo.username)%>
          </td>
        </tr>
<%         if (userInfo.labId != LabInfo.INVALID_LAB_ID) {
               labInfo = pageHelper.getLabInfo(labId); %>
        <tr>
          <th class="twoColumnLeft">Lab:</th>
          <td class="twoColumnRight">
             <%=labInfo.name%> (<%= userInfo.labId%>)
          </td>
        </tr>
<%         } else {
               providerInfo = pageHelper.getProviderInfo(userInfo.providerId);%>
        <tr>
          <th class="twoColumnLeft">Provider:</th>
          <td class="twoColumnRight">
            <%=providerInfo.name%> (<%= userInfo.providerId%>)
          </td>
        </tr>
<%         } %>
        <tr>
          <th class="twoColumnLeft">Full name:</th>
          <td class="twoColumnRight">
            <%= HtmlHelper.nullToBlank(userInfo.fullName) %>
          </td>
        </tr>
        <tr>
          <th class="twoColumnLeft">Creation date:</th>
          <td class="twoColumnRight">
            <%= dateFormat.format(userInfo.creationDate) %>
          </td>
        </tr>
        <tr>
          <th class="twoColumnLeft">Inactive date:</th>
<%         if (userInfo.inactiveDate == null) { %>
            <td class="twoColumnRight"></td>
<%         } else { %>
            <td class="twoColumnRight">
              <%=dateFormat.format(userInfo.inactiveDate)%>
            </td>
<%         } %>
        </tr>
      </table>
<%     } else if (userInfo.id != UserInfo.INVALID_USER_ID) {
           // Display a form that will let an existing user be edited %>
      <form method="POST">
        <input type="hidden" name="labId" value="<%=labId%>">
        <table class="adminFormTable">
          <tr>
            <th class="twoColumnLeft">User ID:</th>
            <td class="twoColumnRight">
              <%= userInfo.id %>
            </td>
          </tr>
          <tr>
            <th class="twoColumnLeft">User Name:</th>
            <td class="twoColumnRight">
              <%= HtmlHelper.nullToBlank(userInfo.username) %>
            </td>
          </tr>
<%         if (userInfo.labId != LabInfo.INVALID_LAB_ID) {
               labInfo = pageHelper.getLabInfo(labId); %>
          <tr>
            <th class="twoColumnLeft">Lab Name (ID):</th>
            <td class="twoColumnRight">
              <%= labInfo.name %> (<%= userInfo.labId%>)
            </td>
          </tr>
<%         } else {
               providerInfo = pageHelper.getProviderInfo(providerId); %>
          <tr>
            <th class="twoColumnLeft">Provider Name (ID):</th>
            <td class="twoColumnRight">
              <%=providerInfo.name%> (<%= userInfo.providerId%>)
              <input type="hidden" name="providerLabId" value="<%=providerInfo.labId%>">
            </td>
          </tr>
<%         }  %>
          <tr>
            <th class="twoColumnLeft">Full Name:</th>
            <td class="twoColumnRight">
              <input name="fullName" type="text" size="32" maxlength="32"
               value="<%=HtmlHelper.nullToBlank(userInfo.fullName)%>">
            </td>
          </tr>
          <tr>
            <th class="twoColumnLeft">Creation date:</th>
            <td class="twoColumnRight">
              <%= dateFormat.format(userInfo.creationDate) %>
            </td>
          </tr>
<%         if (labId != LabInfo.INVALID_LAB_ID) {  %>
          <tr>
            <th class="twoColumnLeft">Global Access Level:</th>
            <td class="twoColumnRight">
              <input type="checkbox" name="scientificUser"
                <%= (userInfo.globalAccessLevel
                                       & UserInfo.LAB_SCIENTIFIC_USER_ACCESS)
                                       > 0 ? "checked=\"true\"" : "" %>>
                Scientific User
              <input type="checkbox" name="labAdmin"
                <%= (userInfo.globalAccessLevel & UserInfo.LAB_ADMIN_ACCESS)
                                       > 0 ? "checked=\"true\"" : "" %>>
                Lab Administrator
              <input type="checkbox" name="siteAdmin"
                <%= (userInfo.globalAccessLevel & UserInfo.SITE_ADMIN_ACCESS)
                                       > 0 ? "checked=\"true\"" : "" %>>
                Site Administrator
            </td>
          </tr>
<%         } %>
          <tr><td>&nbsp;</td></tr>
          <tr>
            <th class="twoColumnLeft">Submit:</th>
            <td class="twoColumnRight">
              <input type="submit" value="Submit">
            </td>
          </tr>
          <tr>
            <td colspan="2">
              <hr size="1">
            </td>
          <tr>
            <th class="twoColumnLeft">Deactivate this user:</th>
            <td class="twoColumnRight">
              <input type="submit" name="isActive" id="isActive" 
                     Value="Deactivate"/>
            </td>
          </tr>
          <tr>
            <td colspan="2">
              <hr size="1">
            </td>
          </tr>
          <tr>
            <th colspan="2">
              Reset Password:<br />
              <font class="comment">
                Passwords are limited to 8 characters maximum.<br />&nbsp;
              </font>
            </th> 
          </tr>
          <tr>
            <td class="twoColumnLeft"> New password: </td>
            <td class="twoColumnRight">
              <input name="password1" type="password" size="8" maxlength="8"
                     value="">
            </td>
          </tr>
          <tr>
            <td class="twoColumnLeft"> Confirm new password: </td>
            <td class="twoColumnRight">
              <input name="password2" type="password" size="8" maxlength="8"
                     value="">
            </td>
          </tr>
          <tr>
            <td></td>
            <td class="twoColumnRight">
              <input type="submit" name="resetPassword" value="Submit">
              <input type="hidden" name="labId" value="<%=labId%>">
              <input type="hidden" name="providerId" value="<%=providerId%>">
              <input type="hidden" name="userId" value="<%=userInfo.id%>">
              <input type="hidden" name="username"
                     value="<%=userInfo.username%>">
              <input type="hidden" name="password"
                     value="<%=userInfo.password%>">
            </td>
          </tr>
        </table>
      </form>
<%     } else {
           // Display a form that will let a new user be created %>
      <form method="POST">
        <table class="adminFormTable">
<%         if (labId != LabInfo.INVALID_LAB_ID) {
               labInfo = pageHelper.getLabInfo(labId); %>
          <tr>
            <th class="twoColumnLeft">Lab Name (ID):</th>
            <td class="twoColumnRight">
              <%=labInfo.name%> (<%=labId%>)
            </td>
          </tr>
<%         } else {
               providerInfo = pageHelper.getProviderInfo(providerId); %>
          <tr>
            <th class="twoColumnLeft">Provider Name (ID):</th>
            <td class="twoColumnRight">
              <%=providerInfo.name%> (<%=providerId%>)
              <input type="hidden" name="providerLabId"
                     value="<%=providerInfo.labId%>">
            </td>
          </tr>
<%         } %>
          <tr>
            <th class="twoColumnLeft">Full Name:</th>
            <td class="twoColumnRight">
              <input name="fullName" type="text" size="32" maxlength="32"
                     value="<%= HtmlHelper.nullToBlank(
                                     request.getParameter("fullName"))%>">
            </td>
          </tr>
          <tr>
            <th class="twoColumnLeft">User Name:</th>
            <td class="twoColumnRight">
              <input name="username" type="text" size="8" maxlength="8"
                     value="<%= HtmlHelper.nullToBlank(
                                        request.getParameter("username"))%>">
            </td>
          </tr>
          <tr>
            <th class="twoColumnLeft">Password:</th>
            <td class="twoColumnRight">
              <input name="password" type="password" size="8" maxlength="8"
                     value="">
            </td>
          </tr>
<%         if (labId != LabInfo.INVALID_LAB_ID) {  %>
          <tr>
            <th class="twoColumnLeft">Global Access Level:</th>
            <td class="twoColumnRight">
              <input type="checkbox" name="scientificUser"> Scientific User
              <input type="checkbox" name="labAdmin"> Lab Administrator
              <input type="checkbox" name="siteAdmin"> Site Administrator
            </td>
          </tr>
<%         } %>
          <tr>
            <td></td>
            <td class="twoColumnRight">
              <input type="submit" value="Submit">
              <input type="hidden" name="labId" value="<%=labId%>">
              <input type="hidden" name="providerId" value="<%=providerId%>">
              <input type="hidden" name="userId" value="<%=userInfo.id%>">
            </td>
          </tr>
        </table>
      </form>
<%     }
    } %>
    <jsp:include page="/footer.jsp" />
  </body>
</html>
