<%--
  -- Reciprocal Net project
  -- solve.jsp
  --
  -- 26-Jul-2002: eisiorho wrote first draft
  -- 06-Aug-2002: eisiorho fixed bugs #258, #260
  -- 07-Aug-2002: eisiorho fixed bugs #281
  -- 20-Aug-2002: eisiorho added fields a, b, c, alpha, beta, gamma.
  -- 29-Aug-2002: leqian added localtracking support
  -- 29-Aug-2002: leqian fixed bug #402
  -- 10-Sep-2002: eisiorho added appropriate measurement unit for "scientific
  --              data"
  -- 18-Sep-2002: ekoperda fixed bug #457 (maxlength of textbox for IUPAC name)
  -- 18-Sep-2002: ekoperda fixed bug #462 (incorrect symbol for angstroms)
  --%>
<%@ page session="true" isThreadSafe="true"
         info="Record Structural Results"
         import="org.recipnet.site.wrapper.HtmlHelper"
         import="org.recipnet.site.container.SampleDataInfo"
         import="org.recipnet.site.container.LabInfo"
         import="org.recipnet.site.container.SampleInfo"
         import="org.recipnet.site.container.LocalTrackingConfig"
         import="org.recipnet.site.container.SampleTextInfo"
         import="org.recipnet.site.container.SampleAttributeInfo"
         import="org.recipnet.site.container.SampleAnnotationInfo"
         import="org.recipnet.site.container.SampleHistoryInfo" %>
<%@ include file="/WEB-INF/common.inc" %>
<%-- authController, pageHelper, and replController now available --%>
<%
    if ( !authController.checkUserAuthenticationStatus() ) {
        request.setAttribute("reason", AuthenticationController.AUTHENTICATION_REQUIRED);
%>
<jsp:forward page="/login.jsp" />
<%
    }

    int sampleId = SampleInfo.INVALID_SAMPLE_ID;
    String sampleIdStr = request.getParameter("sampleId");
    if (sampleIdStr == null) {
        ((HttpServletResponse) response).sendError(HttpServletResponse.SC_BAD_REQUEST);
        return;
    } else {
        try {
            sampleId = Integer.parseInt(sampleIdStr);
        } catch (NumberFormatException nfe) {
            ((HttpServletResponse) response).sendError(HttpServletResponse.SC_BAD_REQUEST);
            return;
        }
        if ( !authController.canEditSample(sampleId) ) {
            request.setAttribute("reason", AuthenticationController.INSUFFICIENT_ACCESS);
%>
<jsp:forward page="/login.jsp" />
<%
        }
    }

    /*
     * If control reaches here then the user is authorized to edit the
     * sample specified in his request.
     */

    int sampleHistoryId = SampleHistoryInfo.INVALID_SAMPLE_HISTORY_ID;
    String sampleHistoryIdStr = request.getParameter("sampleHistoryId");
    if (sampleHistoryIdStr == null) {
        ((HttpServletResponse) response).sendError(HttpServletResponse.SC_BAD_REQUEST);
        return;
    } else {
        try {
            sampleHistoryId = Integer.parseInt(sampleHistoryIdStr);
        } catch (NumberFormatException nfe) {
            ((HttpServletResponse) response).sendError(HttpServletResponse.SC_BAD_REQUEST);
            return;
        }
    }
    pageHelper.retrieveSingleSample(sampleId, sampleHistoryId);
    boolean posted = false;
    String method = ((HttpServletRequest) request).getMethod();
    if ("POST".equals(method)) {
	pageHelper.retrieveLocalTrackingConfig();
        posted = true;
        try {
			String fieldValue;
			int fieldType;
			while (pageHelper.moveNextLocalTrackingField(LocalTrackingConfig.VISIBLE_ON_SOLVE)) {
                            fieldType=pageHelper.getCurrentLocalTrackingFieldTextType();
                            fieldValue= request.getParameter("localTracking"+fieldType);
			    if (null==fieldValue || fieldValue.trim().equals(""))
	                	pageHelper.modifyLtaDuringNextAction(fieldType, null);
                            else
				pageHelper.modifyLtaDuringNextAction(fieldType, fieldValue);
			}

            pageHelper.solveSample(sampleId, sampleHistoryId, authController.getUserId(),
                            request.getRemoteAddr(),
                            HtmlHelper.validateOptionalInt(1, SampleDataInfo.INVALID_INT_VALUE, request.getParameter("z")),
                            HtmlHelper.nullToBlank(request.getParameter("space_group")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("a_dimen")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("b_dimen")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("c_dimen")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("alpha")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("beta")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("gamma")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("rf")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("rwf")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("rf2")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("rwf2")),
                            HtmlHelper.validateOptionalDouble(0, SampleDataInfo.INVALID_DOUBLE_VALUE, request.getParameter("goof")),
                            HtmlHelper.nullToBlank(request.getParameter("summary")),
                            HtmlHelper.nullToBlank(request.getParameter("empirical")),
                            HtmlHelper.nullToBlank(request.getParameter("structural")),
                            HtmlHelper.nullToBlank(request.getParameter("moiety")),
                            HtmlHelper.nullToBlank(request.getParameter("trade")),
                            HtmlHelper.nullToBlank(request.getParameter("common")),
                            HtmlHelper.nullToBlank(request.getParameter("smiles")),
                            HtmlHelper.nullToBlank(request.getParameter("iupac")),
                            HtmlHelper.nullToBlank(request.getParameter("comments")) );

            ((HttpServletResponse) response).sendRedirect("sample.jsp?sampleId=" + sampleId);
        } catch (NumberFormatException nfe) {
            /* Validation Error -- drop through as if this was a GET request */
        }
    } else if ( ! "GET".equals(method) ) {
        ((HttpServletResponse) response).sendError(HttpServletResponse.SC_METHOD_NOT_ALLOWED );
          return;
    }

    /*
     * If control reaches here then we have either a POST request with a
     * validation error or a GET request. Can go on and receive info to
     * display.
     */
	pageHelper.retrieveLocalTrackingConfig();
%>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
          "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
  <link rel="stylesheet"
        href="../recipnet.css"
        type="text/css">
    <title>Reciprocal Net - <%= getServletInfo() %></title>
  </head>
  <body>
    <jsp:include page="/header.jsp">
        <jsp:param name="pageTitle" value="<%=getServletInfo() %>" />
    </jsp:include>
<%  if (posted) { %>
    <p class="errorMessage">Validation Error -- please check your entries and
      resubmit</p>
<%  } %>
    <p class="pageInstructions">
      Enter the basic crystal data on the form below and click the
      &quot;Submit&quot; button to record it.
    </p>
    <center>
    <table cellpadding="5" cellspacing="2" border="2" width="840" class="formTable">
      <tr>
        <th colspan="3">Information about the Sample</th>
      </tr>
      <tr>
        <th>Sample Number</th>
        <th>Originating Lab</th>
        <th>Originating Provider</th>
      </tr>
      <tr>
        <td><b><%= pageHelper.getSampleLocalLabId() %></b></td>
        <td><b><%= pageHelper.getSampleLabName() %></b></td>
        <td><b><%= pageHelper.getSampleProviderName() %></b></td>
      </tr>
    </table>
    <br />&nbsp;
    <br />&nbsp;
    <form method="POST">
    <table cellpadding="5" cellspacing="2" border="2" width="840" class="formTable">
      <tr>
        <th colspan="3">Unit Cell Parameters</th>
      </tr>
      <tr>
        <th colspan="1">a</th>
        <th colspan="1">b</th>
        <th colspan="1">c</th>
      </tr>
      <tr>
        <td colspan="1">
          <input type="text" name="a_dimen" id="a_dimen" size="21" maxlength="64"
                 value="<%= (posted) ? request.getParameter("a_dimen") : HtmlHelper.doubleToString(pageHelper.getSampleA(), 6) %>"> &#197;
        </td>
        <td colspan="1">
          <input type="text" name="b_dimen" id="b_dimen" size="21" maxlength="64"
                 value="<%= (posted) ? request.getParameter("b_dimen") : HtmlHelper.doubleToString(pageHelper.getSampleB(), 6) %>"> &#197;
        </td>
        <td colspan="1">
          <input type="text" name="c_dimen" id="c_dimen" size="21" maxlength="64"
                 value="<%= (posted) ? request.getParameter("c_dimen") : HtmlHelper.doubleToString(pageHelper.getSampleC(), 6) %>"> &#197;
        </td>
      </tr>
      <tr>
        <th colspan="3">The Angle Between Measurement, in degrees</th>
      </tr>
      <tr>
        <th colspan="1">&alpha;  (alpha)</th>
        <th colspan="1">&beta;  (beta)</th>
        <th colspan="1">&gamma;  (gamma)</th>
      </tr>
      <tr>
        <td colspan="1">
          <input type="text" name="alpha" id="alpha" size="21" maxlength="64"
                 value="<%= (posted) ? request.getParameter("alpha") : HtmlHelper.doubleToString(pageHelper.getSampleAlpha(), 6) %>"> &#176;
        </td>
        <td colspan="1">
          <input type="text" name="beta" id="beta" size="21" maxlength="64"
                 value="<%= (posted) ? request.getParameter("beta") : HtmlHelper.doubleToString(pageHelper.getSampleBeta(), 6) %>"> &#176;
        </td>
        <td colspan="1">
          <input type="text" name="gamma" id="gamma" size="21" maxlength="64"
                 value="<%= (posted) ? request.getParameter("gamma") : HtmlHelper.doubleToString(pageHelper.getSampleGamma(), 6) %>"> &#176;
        </td>
      </tr>
    </table>
      <input type="hidden" name="sampleId" value="<%=sampleId%>">
      <table cellpadding="5" cellspacing="2" border="2" width="840" class="formTable">
        <tr>
          <th colspan="4">Summary</th>
        </tr>
        <tr>
          <td colspan="4">
            <textarea name="summary" id="summary" rows="5" cols="75"
                      wrap="hard"><%= posted ? request.getParameter("summary") : HtmlHelper.nullToBlank(pageHelper.getSampleSummary()) %></textarea>
          </td>
        </tr>
        <tr>
          <th colspan="2"># of Molecules in Unit Cell</th>
          <th colspan="1">Goodness of Fit</th>
          <th colspan="1">Space Group</th>
        </tr>
        <tr>
          <td colspan="2">
            <center>
              <input type="text" name="z" id="z" size="32" maxlength="32"
                     value="<%= posted ? request.getParameter("z") : HtmlHelper.intToString(pageHelper.getSampleZ()) %>" >
            </center>
          </td>
          <td colspan="1">
            <center>
              <input type="text" name="goof" id="goof" size="20" maxlength="64"
                     value="<%= posted ? request.getParameter("goof") : HtmlHelper.doubleToString(pageHelper.getSampleGoof(), 3) %>">
            </center>
          </td>
          <td colspan="1">
            <center>
              <input type="text" name="space_group" id="space_group" size="20" maxlength="64"
                     value="<%= posted ? request.getParameter("space_group") : HtmlHelper.nullToBlank(pageHelper.getSampleSpaceGroup()) %>">
            </center>
          </td>
        </tr>
        <tr>
          <th colspan="4">A Statistical Agreement Between the Calculated
                          Data and the Observed Data</th>
        </tr>
        <tr>
          <th colspan="1">RF</th>
          <th colspan="1">R(F &#178;)</th>
          <th colspan="1">RWF</th>
          <th colspan="1">RW(F &#178;)</th>
        </tr>
        <tr>
          <td colspan="1">
            <input type="text" name="rf" id="rf" size="20" maxlength="64"
                   value="<%= posted ? request.getParameter("rf") : HtmlHelper.doubleToString(pageHelper.getSampleRf(), 4) %>">
          </td>
          <td colspan="1">
            <input type="text" name="rf2" id="rf2" size="20" maxlength="64"
                   value="<%= posted ? request.getParameter("rf2") : HtmlHelper.doubleToString(pageHelper.getSampleRf2(), 4) %>">
          </td>
          <td colspan="1">
            <input type="text" name="rwf" id="rwf" size="20" maxlength="64"
                   value="<%= posted ? request.getParameter("rwf") : HtmlHelper.doubleToString(pageHelper.getSampleRwf(), 4) %>">
          </td>
          <td colspan="1">
            <input type="text" name="rwf2" id="rwf2" size="20" maxlength="64"
                   value="<%= posted ? request.getParameter("rwf2") : HtmlHelper.doubleToString(pageHelper.getSampleRwf2(), 4) %>">
          </td>
        </tr>
        <tr>
          <th colspan="2">Empirical Formula (Optional)</th>
          <th colspan="2">Structural Formula (Optional)</th>
        </tr>
        <tr>
          <td colspan="2">
            <center>
              <input type="text" name="empirical" id="empirical" size="32" maxlength="128"
                     value="<%= posted ? request.getParameter("empirical") : HtmlHelper.nullToBlank(pageHelper.getNextAttributeValue(SampleTextInfo.EMPIRICAL_FORMULA)) %>">
            </center>
          </td>
          <td colspan="2">
            <center>
              <input type="text" name="structural" id="structural" size="32" maxlength="128"
                     value="<%= posted ? request.getParameter("structural") : HtmlHelper.nullToBlank(pageHelper.getNextAttributeValue(SampleTextInfo.STRUCTURAL_FORMULA)) %>">
            </center>
          </td>
        </tr>
        <tr>
          <th colspan="2">Moiety Formula (Optional)</th>
          <th colspan="2">SMILES Formula (Optional)</th>
        </tr>
        <tr>
          <td colspan="2">
            <center>
              <input type="text" name="moiety" id="moiety" size="32" maxlength="128"
                     value="<%= posted ? request.getParameter("moiety") : HtmlHelper.nullToBlank(pageHelper.getNextAttributeValue(SampleTextInfo.MOIETY_FORMULA)) %>">
            </center>
          </td>
          <td colspan="2">
            <center>
              <input type="text" name="smiles" id="smiles" size="32" maxlength="128"
                     value="<%= posted ? request.getParameter("smiles") : (pageHelper.moveNextSampleAnnotation(SampleTextInfo.SMILES_FORMULA) ? HtmlHelper.nullToBlank(pageHelper.getAnnotationValue()) : "") %>">
            </center>
          </td>
        </tr>
        <tr>
          <th colspan="2">Trade Name (Optional)</th>
          <th colspan="1">Common Name (Optional)</th>
          <th colspan="1">IUPAC Name (Optional)</th>
        </tr>
        <tr>
          <td colspan="2">
            <center>
              <input type="text" name="trade" id="trade" size="30" maxlength="128"
                     value="<%= posted ? request.getParameter("trade") : HtmlHelper.nullToBlank(pageHelper.getNextAttributeValue(SampleTextInfo.TRADE_NAME)) %>">
            </center>
          </td>
          <td colspan="1">
            <center>
              <input type="text" name="common" id="common" size="20" maxlength="128"
                     value="<%= posted ? request.getParameter("common") : HtmlHelper.nullToBlank(pageHelper.getNextAttributeValue(SampleTextInfo.COMMON_NAME)) %>">
            </center>
          </td>
          <td colspan="1">
            <center>
              <input type="text" name="iupac" id="iupac" size="20"
                     value="<%= posted ? request.getParameter("iupac") : (pageHelper.moveNextSampleAnnotation(SampleTextInfo.IUPAC_NAME) ? HtmlHelper.nullToBlank(pageHelper.getAnnotationValue()) : "") %>">
            </center>
          </td>
        </tr>
		<%
		while (pageHelper.moveNextLocalTrackingField(LocalTrackingConfig.VISIBLE_ON_SOLVE)) {
		%>
		<tr>
			<th>
			<%=pageHelper.getCurrentLocalTrackingFieldName()%>:
			</th>
			<td colspan="3">
			<% int ltType=pageHelper.getCurrentLocalTrackingFieldTextType(); %>
			<input type="text" name="localTracking<%=ltType%>"
				size="64" value="<%=posted?HtmlHelper.nullToBlank(
					request.getParameter("localTracking"+ltType)):
					HtmlHelper.nullToBlank(pageHelper.getNextAttributeValue(ltType))%>">
			</td>
		</tr>
		<%
		}
		%>
        <tr>
          <th colspan="4">Comments on what this information means. (Optional)</th>
        </tr>
        <tr>
          <td colspan="4">
            <textarea name="comments" id="comments" rows="5" cols="75"
                      wrap="hard"><%= HtmlHelper.nullToBlank(request.getParameter("comments")) %></textarea>
          </td>
        </tr>
      </table>
      <input type="submit" value="Submit">
      <input type="reset" value="Reset">
    </form>
    </center>
    <jsp:include page="/footer.jsp" />
  </body>
</html>
