<%--
  -- login.jsp
  --
  -- 22-Jul-2002: hclin wrote first draft
  -- 06-Aug-2002: hclin fixed bug #246
  -- 09-Aug-2002: hclin fixed bug #318
  -- 03-Sep-2002: eisiorho added new feature, so that if the user was
                    forwarded from a previous page because of an error,
                    the user upon correct Authentication will be
                    redirected back to the page they desired, instead of
                    being forwarded back as before.
  -- 20-Nov-2002: ekoperda fixed bug #609
  -- 21-Nov-2002: ekoperda fixed bug #611
  -- 13-Dec-2002: adharurk fixed bug #634
  --%>
<%!
  /**
   * Decides which page the user's browser should be redirected to once a
   * successful login occurs.
   * @returns true if the user's browser should be redirected to index.jsp,
   *     or false if it should be redirected to urlFirstRequested.
   * @param thisPagesName the name of this page (servlet), relative to the web
   *     app's context root.  It is conceivable that a user might arrive at
   *     this page even if he requested a different one, if the page (servlet)
   *     he requested passed control to this one with a JSP 'forward'
   *     directive.  In the current implementation, this will always be
   *     "login.jsp".
   * @param urlFirstRequested the full URL the user's browser requested on the
   *     first HTTP round-trip that arrived at this page (servlet).  It is
   *     conceivable that this might be not be "login.jsp" if the user
   *     requested a different page, an authentication/authorization failure
   *     occurred, and control got passed to this one (via JSP's 'forward'
   *     directive).  This value must be preserved by the caller across
   *     consecutive requests to this page (the login page) -- during
   *     subsequent form post-backs, for example.  This may be null if the
   *     urlFirstRequested parameter used in a call to this function on a
   *     previous HTTP round trip has been lost (perhaps because a malicious
   *     user deleted a form field).
   */
   public boolean toIndexJsp(String thisPagesName, String urlFirstRequested) {
      if (urlFirstRequested == null || "".equals(urlFirstRequested)) {
          return true;
      } else if (urlFirstRequested.indexOf(thisPagesName) >= 0) {
          return true;
      }
      return false;
  }
%>
<%@page session="true" isThreadSafe="true"
        info="Site Login"
        import="org.recipnet.site.wrapper.HtmlHelper"
        import="java.util.Enumeration"
        import="java.net.URL"
        import="javax.naming.AuthenticationException" %>
<%@include file="/WEB-INF/common.inc" %>
<%-- authController, pageHelper, and replController now available --%>
<%
    boolean posted = false;
    HttpServletRequest httpRequest = (HttpServletRequest) request;
    String contextPath = httpRequest.getContextPath();
    String method = httpRequest.getMethod();

    if ("POST".equals(method)) {
        posted = true;
        String username = request.getParameter("username");
        String password = request.getParameter("password");

        /*
         * Go to the try block only if both the username and password are not
         * null/empty string, and the user has not been authorized, else
         * display the login form.
         */
        if (!"".equals(username) && !"".equals(password)
                && username != null && password != null
                && !authController.checkUserAuthenticationStatus()) {
            try {
                authController.login(username, password);
                if (toIndexJsp(request.getServletPath().toString(),
                        request.getParameter("origURL"))) {
                    // The relative url is fine because this code is only
                    // reached on 2nd and subsequent round trips, where the
                    // user POSTed to login.jsp.
                    ((HttpServletResponse) response).sendRedirect("index.jsp");
                    return;
                } else {
                    response.sendRedirect(request.getParameter("origURL"));
                    return;
                }
            } catch (AuthenticationException ex) {
                request.setAttribute("reason", ex.getMessage());
                // Drop through and display the form again
            }
        }
    } else if ( ! "GET".equals(method) ) {
        ((HttpServletResponse) response).sendError(
                                    HttpServletResponse.SC_METHOD_NOT_ALLOWED);
        return;
    }

    /*
     * If control reaches here then we have an AuthenticationException,
     * validation errors (either username or password is an empty string or a
     * null value) or a GET request.
     */
%>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
          "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
    <title>Reciprocal Net - <%=getServletInfo() %></title>
    <link href="<%=contextPath%>/recipnet.css" rel="stylesheet"
            type="text/css" />
  </head>
  <body OnLoad="document.login.username.focus();">
    <jsp:include page="/header.jsp">
        <jsp:param name="pageTitle" value="<%=getServletInfo() %>" />
    </jsp:include>
    <br/>
<%
    /*
     * The login form will display only if the user has not been authorized.
     * If the user has been authorized but tried to access a protected page
     * without the appropriate privilege then ask the user to logout and login
     * as a different user.
     */
    if (!authController.checkUserAuthenticationStatus()) { %>
        <form method="POST" id="login" name="login"
                action="<%= request.getContextPath()
                            + request.getServletPath() %>">
          <table align="center" class="loginBox">
            <tr><th>User Name:</th></tr>
            <tr>
              <td>
                <input name="username" type="text"
                        value="<%= HtmlHelper.nullToBlank(
                        request.getParameter("username")) %>" />
              </td>
            </tr>
            <tr><th>Password:</th></tr>
            <tr>
              <td>
		<input name="password" type="password" maxlength="8" value="">
	      </td>
	    </tr>
	    <tr>
	      <td>
		<input type="submit" value="Log In" />
		<input type="hidden" name="origURL" id="origURL"
                        value="<%= request.getParameter("origURL") != null
		        ? request.getParameter("origURL")
                        : request.getRequestURL() + "?" +
                        HtmlHelper.nullToBlank(request.getQueryString()) %>" />
	      </td>
	    </tr>
	  </table>
	</form> <%
        if (request.getAttribute("reason") != null
                && !request.getAttribute("reason").equals("")) { %>
            <div align="center" class="reason">
	      <%= request.getAttribute("reason")%>
            </div> <%
	}
    } else if (authController.INSUFFICIENT_ACCESS.equals(
            request.getAttribute("reason"))) { %>
        <p>
	  You are not authorized to access requested page. If you need to log
	  in as a different user please log out first.
        </p>
        <form action="<%=contextPath%>/logout.jsp" method="POST">
          <input type="submit" value="Log out" />
        </form> <%
    } %>
    <jsp:include page="/footer.jsp" />
  </body>
</html>
