<%--
  -- Reciprocal Net project
  -- search.jsp
  --
  -- 30-Jul-2002: rlauer wrote first draft
  -- 01-Aug-2002: hclin modified first draft
  -- 06-Aug-2002: ekoperda added "browse mode" feature
  -- 06-Aug-2002: hclin fixed bug #268
  -- 07-Aug-2002: jobollin multiple changes:
  --              modifiPageHelper.storeSearchParamsed internals to avoid
  --              multiple invocations of request.getParameter() and
  --              concomittant revalidation; corrected pervasive problems with
  --              comparing double values to NaN via == and/or != ; made
  --              selected lab and limit to provider options "sticky" across
  --              validation errors; reformatted the search form; corrected
  --              problems that led to invalid range values being stored in the
  --              SearchParams container
  -- 12-Aug-2002: leqian fixed bug #337
  -- 22-Aug-2002: leqian added range check for minZ and maxZ, task #338
  -- 26-Aug-2002: leqian removed authController.setIdValue call, task #370
  -- 04-Sep-2002: jobollin removed extraneous carriage return characters from
  --              the source
  -- 06-Sep-2002: jobollin implemented a constraint by sample provider
  --              option for laboratory staff users
  -- 24-Sep-2002: eisiorho added better pagination, task #444
  -- 15-Oct-2002: ekoperda added support for the requireLocalHolding field on
  --              SearchParams
  -- 17-Oct-2002: eisiorho added ordering of search results.
  -- 31-Oct-2002: eisiorho changed option menu, from 'All' to 500 samples
  --              maximum shown per page.
  -- 13-Dec-2002: adharurk added ordering of search results for browse mode.
  --%>
<%@page session="true" isThreadSafe="true"
        info="Site Search"
        import="org.recipnet.site.wrapper.HtmlHelper"
        import="org.recipnet.site.container.SearchParams"
        import="org.recipnet.site.container.LabInfo"
        import="org.recipnet.site.container.ProviderInfo"
        import="org.recipnet.site.container.SampleDataInfo"
        import="org.recipnet.site.container.UserInfo"
        import="java.util.Iterator"
        import="java.util.List" %>
<%@ include file="/WEB-INF/common.inc" %>
<%
    boolean posted = "POST".equals(((HttpServletRequest) request).getMethod());

    /* Make sure we weren't called with an invalid HTTP method */
    if (! "GET".equals( ((HttpServletRequest) request).getMethod())
            && ! posted) {
        ((HttpServletResponse) response).sendError(
                HttpServletResponse.SC_METHOD_NOT_ALLOWED );
        return;
    }

    SearchParams searchContainer = pageHelper.getEmptySearchParams();
    boolean doSearch = false;
    String defaultRange = "3.0";

    /* search form parameters */
    String localSampleId = HtmlHelper.nullToBlank(
            request.getParameter("localSampleId"));
    int labSearch = HtmlHelper.validateOptionalInt(
            SampleDataInfo.INVALID_INT_VALUE, SampleDataInfo.INVALID_INT_VALUE,
            request.getParameter("labSearch"));
    if (labSearch == SampleDataInfo.INVALID_INT_VALUE) {
        labSearch = SearchParams.DONT_MATCH_INT;
    }
    int providerSearch = HtmlHelper.validateOptionalInt(
            SampleDataInfo.INVALID_INT_VALUE, SampleDataInfo.INVALID_INT_VALUE,
            request.getParameter("providerConstraint"));
    if (providerSearch == SampleDataInfo.INVALID_INT_VALUE) {
        providerSearch = SearchParams.DONT_MATCH_INT;
    }
    boolean providerChecked = "1".equals(
            request.getParameter("providerChecked"));
    boolean requireLocalHolding = "1".equals(
            request.getParameter("requireLocalHolding"));

    String minZStr = HtmlHelper.nullToBlank(
            request.getParameter("minZ")).trim();
    String maxZStr = HtmlHelper.nullToBlank(
            request.getParameter("maxZ")).trim();
    String chemName = HtmlHelper.nullToBlank(
            request.getParameter("chemName")).trim();
    String structuralFormula = HtmlHelper.nullToBlank(
            request.getParameter("structuralFormula")).trim();
    String empiricalFormula = HtmlHelper.nullToBlank(
            request.getParameter("empiricalFormula")).trim();
    String moietyFormula = HtmlHelper.nullToBlank(
            request.getParameter("moietyFormula")).trim();
    String crystallographer =  HtmlHelper.nullToBlank(
            request.getParameter("crystallographer")).trim();
    String spacegroup = HtmlHelper.nullToBlank(
            request.getParameter("spacegroup")).trim();
    String aStr = HtmlHelper.nullToBlank(
            request.getParameter("cellA")).trim();
    String rangeAStr = HtmlHelper.nullToDefault(
            request.getParameter("rangeCellA"), defaultRange).trim();
    String bStr = HtmlHelper.nullToBlank(
            request.getParameter("cellB")).trim();
    String rangeBStr = HtmlHelper.nullToDefault(
            request.getParameter("rangeCellB"), defaultRange).trim();
    String cStr = HtmlHelper.nullToBlank(request.getParameter("cellC")).trim();
    String rangeCStr = HtmlHelper.nullToDefault(
            request.getParameter("rangeCellC"), defaultRange).trim();
    String alphaStr = HtmlHelper.nullToBlank(
            request.getParameter("alpha")).trim();
    String rangeAlphaStr = HtmlHelper.nullToDefault(
            request.getParameter("rangeAlpha"), defaultRange).trim();
    String betaStr = HtmlHelper.nullToBlank(
            request.getParameter("beta")).trim();
    String rangeBetaStr = HtmlHelper.nullToDefault(
            request.getParameter("rangeBeta"), defaultRange).trim();
    String gammaStr = HtmlHelper.nullToBlank(
            request.getParameter("gamma")).trim();
    String rangeGammaStr = HtmlHelper.nullToDefault(
            request.getParameter("rangeGamma"), defaultRange).trim();
    String tempStr = HtmlHelper.nullToBlank(
            request.getParameter("temp")).trim();
    String rangeTempStr = HtmlHelper.nullToDefault(
            request.getParameter("rangeTemp"), defaultRange).trim();
    String volumeStr = HtmlHelper.nullToBlank(
            request.getParameter("volume")).trim();
    String rangeVolumeStr = HtmlHelper.nullToDefault(
            request.getParameter("rangeVolume"), defaultRange).trim();
    String densityStr = HtmlHelper.nullToBlank(
            request.getParameter("density")).trim();
    String rangeDensityStr = HtmlHelper.nullToDefault(
            request.getParameter("rangeDensity"), defaultRange).trim();

    /* Detect whether we should be in "quick search" mode */
    if (request.getParameter("quickSearch") != null) {
        searchContainer.genericSampleId = request.getParameter("quickSearch");
        doSearch = true;

    /* Detect whether a "browse" was requested */
    } else if ("1".equals(request.getParameter("browse"))) {
        // We deliberately fail to populate the searchContainer.  This will
        // result in all samples being matched. Sort the results in order of 
        // local lab Id for convenience.
        searchContainer.sortOrder = SearchParams.SORTBY_LOCALLABID; 
        doSearch = true;

    /*
     * Detect whether to extract and validate the search form parameters and
     * populate the search container from them
     */
    } else if (posted) {

        try {
            if (!localSampleId.equals("")) {
                searchContainer.localSampleId = localSampleId;
            }
            searchContainer.labSearch = labSearch;
            searchContainer.provider = providerSearch;
            if ( providerChecked ) {
                searchContainer.provider = authController.getProviderId();
            }
            if (requireLocalHolding) {
                searchContainer.requireLocalHolding = true;
            }

            int minZ = HtmlHelper.validateOptionalInt(1,
                    SampleDataInfo.INVALID_INT_VALUE, minZStr);
            if (minZ != SampleDataInfo.INVALID_INT_VALUE) {
                searchContainer.minZ = minZ;
            }
            int maxZ = HtmlHelper.validateOptionalInt(1,
                    SampleDataInfo.INVALID_INT_VALUE, maxZStr);
            if (maxZ != SampleDataInfo.INVALID_INT_VALUE) {
                searchContainer.maxZ = maxZ;
            }
            // Check whether minZ<maxZ
            if (minZ != SampleDataInfo.INVALID_INT_VALUE
                    && maxZ != SampleDataInfo.INVALID_INT_VALUE
                    && minZ > maxZ) {
		// This is not really a number format error, but we pretend it
        // is so that the "Validation Error" message will be displayed.
		throw new NumberFormatException();
            }
            try {
                searchContainer.sortOrder =
                        Integer.parseInt(request.getParameter("searchby"));
            } catch (NumberFormatException nfe) {
                ((HttpServletResponse) response).sendError(
                        HttpServletResponse.SC_BAD_REQUEST);
            }
            if (!chemName.equals("")) {
                searchContainer.chemName = chemName;
            }
            if (!structuralFormula.equals("")) {
                searchContainer.structFormula = structuralFormula;
            }
            if (!empiricalFormula.equals("")) {
                searchContainer.empirFormula = empiricalFormula;
            }
            if (!moietyFormula.equals("")) {
                searchContainer.moietyFormula = moietyFormula;
            }
            if (!crystallographer.equals("")) {
                searchContainer.crystallographer = crystallographer;
            }
            if (!spacegroup.equals("")) {
                searchContainer.spaceGroup = spacegroup;
            }
            double a = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, aStr);
            if (Double.compare(a, SampleDataInfo.INVALID_DOUBLE_VALUE) != 0) {
                searchContainer.a = a;
            }
            double rangeA = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, rangeAStr);
            if (Double.compare(rangeA, SampleDataInfo.INVALID_DOUBLE_VALUE) != 0) {
                searchContainer.rangeA = rangeA;
            }
            double b = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, bStr);
            if (Double.compare(b, SampleDataInfo.INVALID_DOUBLE_VALUE) != 0) {
                searchContainer.b = b;
            }
            double rangeB = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, rangeBStr);
            if (Double.compare(rangeB, SampleDataInfo.INVALID_DOUBLE_VALUE) 
                    != 0) {
                searchContainer.rangeB = rangeB;
            }
            double c = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, cStr);
            if (Double.compare(c, SampleDataInfo.INVALID_DOUBLE_VALUE) != 0) {
                searchContainer.c = c;
            }
            double rangeC = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, rangeCStr);
            if (Double.compare(rangeC, SampleDataInfo.INVALID_DOUBLE_VALUE) 
                    != 0) {
                searchContainer.rangeC = rangeC;
            }
            double alpha = HtmlHelper.validateOptionalDouble(0d, 180d,
                    alphaStr);
            if (Double.compare(alpha, SampleDataInfo.INVALID_DOUBLE_VALUE) 
                    != 0) {
                searchContainer.alpha = alpha;
            }
            double rangeAlpha = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, rangeAlphaStr);
            if (Double.compare(rangeAlpha, SampleDataInfo.INVALID_DOUBLE_VALUE)
                    != 0) {
                searchContainer.rangeAlpha = rangeAlpha;
            }
            double beta = HtmlHelper.validateOptionalDouble(0d, 180d, betaStr);
            if (Double.compare(beta, SampleDataInfo.INVALID_DOUBLE_VALUE) 
                    != 0) {
                searchContainer.beta = beta;
            }
            double rangeBeta = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, rangeBetaStr);
            if (Double.compare(rangeBeta, SampleDataInfo.INVALID_DOUBLE_VALUE) 
                    != 0) {
                searchContainer.rangeBeta = rangeBeta;
            }
            double gamma = HtmlHelper.validateOptionalDouble(0d, 180d, 
                    gammaStr);
            if (Double.compare(gamma, SampleDataInfo.INVALID_DOUBLE_VALUE) 
                    != 0) {
                searchContainer.gamma = gamma;
            }
            double rangeGamma = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, rangeGammaStr);
            if (Double.compare(rangeGamma, SampleDataInfo.INVALID_DOUBLE_VALUE)
                    != 0) {
                searchContainer.rangeGamma = rangeGamma;
            }
            double temp = HtmlHelper.validateOptionalDouble(-273.15d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, tempStr);
            if (Double.compare(temp, SampleDataInfo.INVALID_DOUBLE_VALUE) 
                    != 0) {
                searchContainer.temp = temp;
            }
            double rangeTemp = HtmlHelper.validateOptionalDouble(0d,
                SampleDataInfo.INVALID_DOUBLE_VALUE, rangeTempStr);
            if (Double.compare(rangeTemp, SampleDataInfo.INVALID_DOUBLE_VALUE)
                    != 0) {
                searchContainer.rangeTemp = rangeTemp;
            }
            double volume = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, volumeStr);
            if (Double.compare(volume, SampleDataInfo.INVALID_DOUBLE_VALUE) 
                    != 0) {
                searchContainer.volume = volume;
            }
            double rangeVolume = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, rangeVolumeStr);
            if (Double.compare(rangeVolume, SampleDataInfo.INVALID_DOUBLE_VALUE
                    ) != 0) {
                searchContainer.rangeVolume = rangeVolume;
            }
            double density = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, densityStr);
            if (Double.compare(density, SampleDataInfo.INVALID_DOUBLE_VALUE) 
                    != 0) { 
                searchContainer.density = density;
            }
            double rangeDensity = HtmlHelper.validateOptionalDouble(0d,
                    SampleDataInfo.INVALID_DOUBLE_VALUE, rangeDensityStr);
            if (Double.compare(rangeDensity, SampleDataInfo.INVALID_DOUBLE_VALUE) != 0) {
                searchContainer.rangeDensity = rangeDensity;
            }

            doSearch = true;
        } catch (NumberFormatException nfe) {
            // No need to do anything right now.  doSearch=false and
            //   posted=true.  This will cause the page to be redisplayed with
            //   a "validation error" message at the top.
        }
    }

    /* Run the search now if we have enough information to do so */
    if (doSearch) {
        // pass the search down to the core and redirect to searchresults.jsp
        int searchId = pageHelper.storeSearchParams(searchContainer);
        String pageSize = request.getParameter("pageSize");
        if (pageSize == null || "".equals(pageSize)) {
            pageSize = "10";
        }
        ((HttpServletResponse) response).sendRedirect(
                "searchresults.jsp?searchId=" + searchId + "&pageSize="
                + pageSize);
        return;
    }

    /**
     * If control reaches here then we have either a POST request with a
     * validation error or a GET request.
     */
%>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
                      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
    <title>Reciprocal Net - <%=getServletInfo() %></title>
    <link href="recipnet.css" rel="stylesheet" type="text/css" />
  </head>
  <body>
    <jsp:include page="/header.jsp">
        <jsp:param name="pageTitle" value="<%=getServletInfo() %>" />
    </jsp:include>
    <br />
<%  if (posted) { %>
    <p class="errorMessage">
      Validation Error -- please check your entries and resubmit.
    </p>
<%  } %>
<form method="POST">
<table class="searchTable" align="center">
  <tr>
    <th colspan="4" class="searchTableHeader">Sample Identification</th>
  </tr>
  <tr class="searchTableSubHeader">
    <th class="twoColumnLeft" class="searchTableColumnWidth">Sample number:
    </th>
    <td class="searchTableColumnWidth"><input name="localSampleId" type="text"
       size="10" maxlength="32" value="<%= localSampleId %>" tabindex="1" />
    </td>
    <th class="twoColumnLeft" class="searchTableColumnWidth">Laboratory: </th>
    <td class="searchTableColumnWidth"><select name="labSearch" tabindex="1">
      <option value="<%= SearchParams.DONT_MATCH_INT %>"
        <%= (labSearch == SearchParams.DONT_MATCH_INT) ? "selected='selected'"
                                                     : "" %> >All Labs</option>
<%
          // Fill the combo box with the names of all labs in Reciprocal Net.
          Iterator i = pageHelper.getAllLabInfo().iterator();
          while (i.hasNext()) {
              LabInfo lab = (LabInfo) i.next();
%>
      <option value="<%=lab.id%>"
        <%= (labSearch == lab.id) ? "selected='selected'" : "" %> ><%=lab.name%>
      </option>
<%        } %>
      </select>
    </td>
  </tr>
<%
  if (authController.isLabUser()) {
      List providers = pageHelper.getAllProviderInfo(authController.getLabId());
      Iterator iter = providers.iterator(); %>
      <tr class="searchTableSubHeader">
        <th class="twoColumnLeft">Submitted by group:</th>
        <td colspan="3">
          <select name="providerConstraint">
            <option value="<%=SearchParams.DONT_MATCH_INT%>"
              <%= (providerSearch == SearchParams.DONT_MATCH_INT)
                    ? "selected='yes'" : "" %> >any group</option>
<%
            while (iter.hasNext()) {
                ProviderInfo provider = (ProviderInfo) iter.next(); %>
            <option value="<%=provider.id%>"
              <%= (providerSearch == provider.id) ? "selected='yes'" : "" %> >
              <%= provider.name%></option>
<%          } %>
          </select>
        </td>
      </tr>
<%} %>
  <tr class=searchTableSubHeader">
    <th class="twoColumnLeft" valign="top">Constrain search to:</th>
    <td colspan="3" class="twoColumnRight">
      <input name="requireLocalHolding" type="checkbox" value="1"
              <%= requireLocalHolding ? "checked='1'" : "" %> tabindex="6" />
      samples with data at the local site
<%
      if (authController.isProviderUser()) { %>
	  <br />
          <input name="providerChecked" type="checkbox" value="1"
                  <%= providerChecked ? "checked='1'" : "" %> tabindex="6" />
          samples submitted by my group
          (<%= authController.getProviderName() %>)
<%    } %>
    </td>
  </tr>
  <tr>
    <th colspan="4" class="searchTableHeader">Name and Formulae</th>
  </tr>
  <tr class="searchTableSubHeader">
    <th class="twoColumnLeft">Compound Name: </th>
    <td><input name="chemName" type="text" size="15"
               value="<%= chemName %>" tabindex="6" /></td>
    <th class="twoColumnLeft">Empirical Formula: </th>
    <td><input name="empiricalFormula" type="text" size="15"
               value="<%= empiricalFormula %>" tabindex="6" /></td>
  </tr>
  <tr class="searchTableSubHeader">
    <th class="twoColumnLeft">Structural Formula: </th>
      <td><input name="structuralFormula" type="text" size="15"
               value="<%= structuralFormula %>" tabindex="6" /></td>
    <th class="twoColumnLeft">Moiety Formula: </th>
    <td><input name="moietyFormula" type="text" size="15"
               value="<%= moietyFormula %>" tabindex="6" /></td>
  </tr>
  <tr class="searchTableSubHeader">
    <th class="twoColumnLeft">Crystallographer:</th>
    <td colspan="3"><input name="crystallographer" type="text" size="25"
                           value="<%= crystallographer %>" tabindex="6" /></td>
  </tr>
  <tr>
    <th colspan="4" class="searchTableHeader">Crystallographic Data Search
       Criteria</th>
  </tr>
  <tr>
    <th class="twoColumnLeft">a:</th>
    <td><input name="cellA" type="text" value="<%= aStr %>"
               size="5" tabindex="11" />&nbsp;&#177;&nbsp;
        <input name="rangeCellA" type="text" value="<%= rangeAStr %>"
               size="5" tabindex="11" />% </td>
    <th class="twoColumnLeft">&alpha; (Alpha):</th>
    <td><input name="alpha" type="text" value="<%= alphaStr %>"
               size="5" tabindex="16" />&nbsp;&#177;&nbsp;
        <input name="rangeAlpha" type="text" value="<%= rangeAlphaStr %>"
               size="5" tabindex="16" />% </td>
  </tr>
  <tr>
    <th class="twoColumnLeft">b:</th>
    <td><input name="cellB" type="text" value="<%= bStr %>"
               size="5" tabindex="11" />&nbsp;&#177;&nbsp;
        <input name="rangeCellB" type="text" value="<%= rangeBStr %>"
               size="5" tabindex="11" />% </td>
    <th class="twoColumnLeft">&beta; (Beta):</th>
    <td><input name="beta" type="text" value="<%= betaStr %>"
               size="5" tabindex="16" />&nbsp;&#177;&nbsp;
        <input name="rangeBeta" type="text" value="<%= rangeBetaStr %>"
               size="5" tabindex="16" />% </td>
  </tr>
  <tr>
    <th class="twoColumnLeft">c:</th>
    <td><input name="cellC" type="text"
               value="<%= cStr %>" size="5" tabindex="11" />&nbsp;&#177;&nbsp;
        <input name="rangeCellC" type="text" value="<%= rangeCStr %>"
               size="5" tabindex="11" />% </td>
    <th class="twoColumnLeft">&gamma; (Gamma):</th>
    <td><input name="gamma" type="text" value="<%= gammaStr %>"
               size="5" tabindex="16" />&nbsp;&#177;&nbsp;
        <input name="rangeGamma" type="text" value="<%= rangeGammaStr %>"
               size="5" tabindex="16" />% </td>
  </tr>
  <tr>
    <th class="twoColumnLeft">Space Group:</th>
    <td colspan="3"><input name="spacegroup" type="text" maxlength="15"
                           value="<%= spacegroup %>" tabindex="21" /></td>
  </tr>
  <tr>
    <th class="twoColumnLeft">Minimum Z:</th>
    <td><input name="minZ" type="text" maxlength="11" tabindex="21"
               value="<%= minZStr %>" size="5" /></td>
    <th class="twoColumnLeft">Maximum Z:</th>
    <td><input name="maxZ" type="text" maxlength="11" tabindex="21"
               value="<%= maxZStr %>" size="5" /></td>
  </tr>
  <tr>
    <th class="twoColumnLeft">Volume:</th>
    <td><input name="volume" type="text"  tabindex="21" value="<%= volumeStr %>"
               size="5" />&nbsp;&#177;&nbsp;
        <input name="rangeVolume" type="text" tabindex="21"
               value="<%= rangeVolumeStr %>" size="5" />% </td>
    <th class="twoColumnLeft">Density:</th>
    <td><input name="density" type="text" tabindex="21"
               value="<%= densityStr %>" size="5" />&nbsp;&#177;&nbsp;
        <input name="rangeDensity" type="text" tabindex="21"
               value="<%= rangeDensityStr %>" size="5" />% </td>
  </tr>
  <tr>
    <th class="twoColumnLeft">Temperature:</th>
    <td><input name="temp" type="text" value="<%= tempStr %>"
               size="5" tabindex="21" />&nbsp;&#177;&nbsp;
        <input name="rangeTemp" type="text" value="<%= rangeTempStr %>"
               size="5" tabindex="21" />% </td>
    <td></td>
  </tr>
  <tr>
  <%-- Full Text Search not yet supported; Future addition: full text search and/or keyword search --%>
    <th colspan="4" class="searchTableHeader">Full Text Search (Not currently supported!)</th>
  </tr>
  <tr>
    <td colspan="4"><textarea name="anyText" cols="80" tabindex="51"
                              rows="5"></textarea></td>
  </tr>
  <tr><td colspan="4">&nbsp;</td></tr>
  <tr>
    <th colspan="4" class="searchTableHeader">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Ordering of Search Results</th>
  </tr>
  <tr class="searchTableSubHeader">
    <th class="twoColumnLeft">Sort results by: </th>
    <td><select name="searchby" id="searchby">
          <option value="<%= SearchParams.SORTBY_LOCALLABID %>" selected="true">Sample number</option>
          <option value="<%= SearchParams.SORTBY_LOCALLABID_REV %>">Sample number (reverse)</option>
          <option value="<%= SearchParams.SORTBY_LABID_LOCALLABID %>">Lab, then sample number</option>
          <option value="<%= SearchParams.SORTBY_LABID_LOCALLABID_REV %>">Lab, then sample number (reverse)</option>
        </select>
    </td>
    <th class="twoColumnLeft">Results per page: </th>
    <td colspan="3">
      <select name="pageSize" id="pageSize">
        <option value="5">5
        <option value="10" selected>10
        <option value="25">25
        <option value="50">50
        <option value="100">100
        <option value="500">500
      </select>
    </td>
  </tr>
  <tr>
    <td colspan="4" align="center">
      <input type="submit" value="Search" size="10" tabindex="101" />&nbsp;
      <input type="reset"  value="Reset"  size="10" tabindex="101" />
    </td>
  </tr>
</table>
</form>
  <jsp:include page="/footer.jsp" />
</body>
</html>
