<%--
  -- Reciprocal Net project
  -- searchresults.jsp
  --
  -- 01-Aug-2002: rlauer wrote first draft
  -- 02-Aug-2002: ekoperda touched up first draft
  -- 08-Aug-2002: ekoperda fixed bugs #296 and #298 (UI refinements)
  -- 21-Aug-2002: eisiorho changed retrieveSearchResults(), retrieves only
  --              partial list of SampleInfos.
  -- 27-Aug-2002: ekoperda fixed compilation bug by importing HtmlHelper again
  -- 13-Sep-2002: jobollin fixed capitalization of page title (task 332) and
  --              removed extra carriage returns
  -- 24-Sep-2002: eisiorho added better pagination, task #444
  -- 17-Oct-2002: eisiorho added 'withdrawn' feature to results display
  -- 31-Oct-2002: eisiorho changed option menu, from 'All' to 500 samples
  --              maximum shown per page
  -- 01-Nov-2002: ekoperda fixed bug #560 that was caused by an incorrect
  --              calling order to PageHelper
  -- 12-Nov-2002: eisiorho fixed bug #598
  -- 18-Nov-2002: ekoperda fixed bug #602
  -- 16-Dec-2002: ekoperda fixed bug #659 by rearranging the order in which
  --              form fields are processed during a GET/POST
  -- 18-Dec-2002: eisiorho updated the display to reflect the
  --              isMoreRecentThanSearch flag in SampleInfo
--%>
<%@page session="true" isThreadSafe="true"
  info="Search Results"
  import="org.recipnet.site.container.LabInfo"
  import="org.recipnet.site.container.SampleAttributeInfo"
  import="org.recipnet.site.container.SampleInfo"
  import="org.recipnet.site.wrapper.HtmlHelper"
 %>
<%@ include file="/WEB-INF/common.inc" %>
<%
// Instantiate useful objects and containers
int searchId;
int pageNumber = 1;
int pageSize;

// Extract the search id from the HTTP request.  Also extract the page number,
//   if it was specified
if (request.getParameter("searchId") == null) {
    ((HttpServletResponse) response).sendError(
            HttpServletResponse.SC_BAD_REQUEST);
    return;
}
try {
    searchId = Integer.parseInt(request.getParameter("searchId"));
    pageSize = Integer.parseInt(request.getParameter("pageSize"));
    if (request.getParameter("page") != null) {
        pageNumber = Integer.parseInt(request.getParameter("page"));
    }
} catch (NumberFormatException nfe) {
    ((HttpServletResponse) response).sendError(
            HttpServletResponse.SC_BAD_REQUEST);
   return;
}

// This code checks to see if the user wishes to resize the number of samples
//    shown on the page. The following logic makes sure that the top
//    sample shown before 'Resize' was clicked is in the new page shown after
//    the resizing.
if (request.getParameter("resize") != null) {
    if (request.getParameter("indexof_Top_Numb") != null) {
        int results =
                Integer.parseInt(request.getParameter("indexof_Top_Numb"));
        int prevpageSize =
                Integer.parseInt(request.getParameter("prevpageSize"));
        if (results == 0) {
            pageNumber = 1;
        } else {
            pageNumber = ((results - 1)/ pageSize) + 1;
        }
        ((HttpServletResponse) response).sendRedirect(
                "searchresults.jsp?searchId=" + searchId + "&page="
                + pageNumber + "&pageSize=" + pageSize);
        return;
    } else {
        ((HttpServletResponse) response).sendRedirect(
                "searchresults.jsp?searchId=" + searchId + "&pageSize="
                + pageSize);
        return;
    }
}

// Retrieve the search results from PageHelper
pageHelper.retrieveSearchResults(searchId, (pageSize * (pageNumber - 1)),
        pageSize);
pageHelper.moveToSample((pageNumber - 1) * pageSize + 1);
int count = pageHelper.getSampleCount();

// Special handling if there is only a single search result - jump directly to
//   the showsample page.
if (pageNumber == 1 && pageHelper.isLastSample()) {
    if (authController.canEditSample(pageHelper.getSampleId())) {
        ((HttpServletResponse) response).sendRedirect(
                        "lab/sample.jsp?sampleId=" + pageHelper.getSampleId());
    } else {
        ((HttpServletResponse) response).sendRedirect(
                "showsample.jsp?sampleId=" + pageHelper.getSampleId());
    }
    return;
}
%>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
                      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
    <title>Reciprocal Net - <%=getServletInfo() %></title>
    <link href="/recipnet/recipnet.css" rel="stylesheet" type="text/css" />
  </head>
  <body>
    <jsp:include page="/header.jsp">
        <jsp:param name="pageTitle" value="<%=getServletInfo() %>" />
    </jsp:include>
    <p>
      Found <font color="red"><b><%=count %></b></font>
      samples.&nbsp; Page <%=pageNumber %> of
      <%= (count - 1) / pageSize + 1 %>.
    </p> <%
    // Display links to the previous and next pages
    if (pageNumber > 1) { %>
    <a href="searchresults.jsp?searchId=<%=searchId %>&page=<%=
            pageNumber - 1 %>&pageSize=<%=pageSize %>" ><<< Previous page
    </a> &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; <%
    }
    if (pageNumber < (count - 1) / pageSize + 1) { %>
    <a href="searchresults.jsp?searchId=<%=searchId %>&page=<%=
        pageNumber + 1 %>&pageSize=<%=pageSize %>" >Next page >>>
    </a>
<%  } %>

    <table cellspacing="15" border="0"> <%
      // Iterate through the search results, until we've displayed pageSize
      // hits or we reach the last one.  i is our hit number, ranging from 1 to
      // n.
      for (int i = (pageNumber - 1) * pageSize + 1;
              i <= pageNumber * pageSize && i <= count; i++) {
          // Retrieve information about this sample here for convenience
          int sampleId = pageHelper.getSampleId();
          boolean withdraw =
                  (SampleInfo.WITHDRAWN == pageHelper.getSampleStatus());
          boolean isMoreRecent = pageHelper.getSampleIsMRTS();
          int sampleLabId = pageHelper.getSampleLabId();
          String sampleLocalLabId = pageHelper.getSampleLocalLabId();
          String providerName = pageHelper.getSampleProviderName();
          LabInfo lab = pageHelper.getLabInfo(sampleLabId);
          String shortLabName = lab.shortName;
          String commonName = pageHelper.getNextAttributeValue(
                    SampleAttributeInfo.COMMON_NAME);
          String empiricalFormula = pageHelper.getNextAttributeValue(
                    SampleAttributeInfo.EMPIRICAL_FORMULA);
          String structuralFormula = pageHelper.getNextAttributeValue(
                    SampleAttributeInfo.STRUCTURAL_FORMULA); %>
          <tr>
            <td align="right" valign="top">
              <%=i %>.
            </td>
            <td align="left" valign="top" width="350">
              <a href="showsample.jsp?sampleId=<%=sampleId %>"><%=
	              shortLabName + " #" + sampleLocalLabId %>
              </a> <%
          if (commonName != null) { %>
                &nbsp;&nbsp;<%=" (" + commonName + ") " %> <%
          }
          if (pageHelper.getSampleStatus() == SampleInfo.WITHDRAWN) {
              out.println("<font color=\"red\"><b>-- withdrawn</b>"
	              + "</font>");
          } %>
              <br /> <%
          if (isMoreRecent) { %>
            <font class="warningMessage">
              This sample has been updated recently and might not match the
              search criteria any longer.
            </font>
            <br /> <%
          }
          if (structuralFormula != null) { %>
                Structural formula: <b>
	          <%=HtmlHelper.prettyHtmlChemicalFormula(structuralFormula) %>
	          </b>
              <br /><%
          } else if (empiricalFormula != null) { %>
                Emprical formula: <b><%=
	          HtmlHelper.prettyHtmlChemicalFormula(empiricalFormula) %></b>
              <br />
<%        } %>
            </td>
            <td width="100" align="right" valign="top"> <%
          if (authController.canEditSample(sampleId)) { %>
                &nbsp; &nbsp; &nbsp; &nbsp;
                <a href="lab/sample.jsp?sampleId=<%=sampleId %>">Edit...</a>
<%        } %>
            </td>
          </tr> <%
	      pageHelper.moveNextSample();
      } // end for loop %>
    </table>
    <br /> <%
    // Display links to other "results pages"
    if (pageNumber > 1) { %>
        <a href="searchresults.jsp?searchId=<%=searchId %>&page=<%=
                pageNumber - 1 %>&pageSize=<%=pageSize %>" ><<< Previous page
        </a> &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; <%
    }
    if (count > pageSize) {
        double hold1 = count;
        double hold2 = pageSize;
        double value = hold1 / hold2;
        if (value < 8) {
            for (int k = 1; k < value + 1; k++) {
                if (k == pageNumber && pageSize != count) { %>
                    <font color="red"><b><%= k %></b></font>&nbsp;&nbsp; <%
                } else if (pageSize != count){ %>
                    <a href="searchresults.jsp?searchId=<%=searchId
                    %>&page=<%= k %>&pageSize=<%=pageSize %>" ><%= k %>
                    </a>&nbsp;&nbsp; <%
               }
            }
        } else {
            for (int k = pageNumber - 3; k < (pageNumber + 4); k++) {
                if (k >= 1) {
                    if (k == pageNumber) { %>
                        <font color="red"><b><%= k %></b></font>&nbsp;&nbsp; <%
                    } else if(k < value + 1){ %>
                        <a href="searchresults.jsp?searchId=<%=searchId
                        %>&page=<%=k %>&pageSize=<%=pageSize %>" ><%= k %>
                        </a>&nbsp;&nbsp; <%
                   }
                }
            }
        }
    }
    if (pageNumber < (pageHelper.getSampleCount() - 1) / pageSize + 1) { %>
        &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;
        <a href="searchresults.jsp?searchId=<%=searchId %>&page=<%=
        pageNumber + 1 %>&pageSize=<%=pageSize %>" >Next page >>></a>
<%  } %>
    <br /><br />

    <form>
      Results per page:
      <select name="pageSize" id="pageSize">
        <option value="5"
	  <%= (pageSize == 5) ? "selected" : "" %>>5</option>
        <option value="10"
	  <%= (pageSize == 10) ? "selected" : "" %>>10</option>
        <option value="25"
	  <%= (pageSize == 25) ? "selected" : "" %>>25</option>
        <option value="50"
	  <%= (pageSize == 50) ? "selected" : "" %>>50</option>
        <option value="100"
	  <%= (pageSize == 100) ? "selected" : "" %>>100</option>
        <option value="500"
	  <%= (pageSize == 500) ? "selected" : "" %>>500</option>
      </select>
      <input type="submit" name="resize" id="resize" value="Resize" />
      <input type="hidden" name="indexof_Top_Numb" id="indexof_Top_Numb"
              value="<%= pageSize * (pageNumber - 1) + 1 %>" />
      <input type="hidden" name="prevpageSize" id="prevpageSize"
              value="<%= pageSize %>" />
      <input type="hidden" name="searchId" id="searchId"
              value="<%= searchId %>" />
      <input type="hidden" name="page" id="page" value="<%= pageNumber %>" />
    </form>
    <jsp:include page="/footer.jsp" />
  </body>
</html>
