<%--
  -- Reciprocal Net project
  -- @(#)showsample.jsp
  -- 
  -- 20-Jun-2002: hclin wrote first draft
  -- 09-Jul-2002: leqian wrote second draft
  -- 08-Aug-2002: leqian fixed bug #314
  -- 14-Aug-2002: leqian did a minor UI change (task #347)
  -- 12-Sep-2002: ekoperda did a major UI redesign to better integrate with the
  --              portal's common molecules section
  -- 18-Sep-2002: ekoperda added measurement units and the formula weight field
  --              to this page's researcher mode UI
  -- 20-Sep-2002: ekoperda removed references to JaMMed, added an informative
  --              title for researcher mode, restricted visibility of
  --              localtracking attributes, and rearranged UI
  -- 26-Sep-2002: ekoperda fixed bug #482 that prevented all annotations from
  --              being displayed
  -- 17-Oct-2002: ekoperda fixed bug #534 that worked around a bug in order-of-
  --              operations logic introduced by Sun's j2sdk1.4.1
  -- 08-Nov-2002: adharurk changed logic in basic view to invoke 
  --              pageHelper.getPreferredChemicalFormula(); added special 
  --              handling for attributes of type EMPIRICAL_FORMULA_xxx
  -- 20-Nov-2002: jobollin updated JaMM parameters
  -- 17-Dec-2002: jobollin fixed malformed HTML output for JaMM 1 appleti
  --              parameters
  -- 17-Dec-2002: jobollin removed applet parameters specifying table.dat
  --              as part of task #509
  -- 19-Dec-2002: eisiorho added logic so that if there is no available .crt
  --              file, no applet will try to load.
  --
  -- The page displays information basic information about a sample.  The exact
  -- layout depends upon the current user's "level".  The current
  -- implementation supports two layout modes: "researcher mode" and "common
  -- molecules mode".
  --
  -- Query-line parameters:
  --   sampleId         required, must be a valid sample id number
  --   sampleHistoryId  optional, must be a valid history id for the sample
  --                    specified.  If omitted, the most recent version of the
  --                    specified sample is displayed.
  --   level            optional, an integer chosen from the constants in 
  --                    SampleAnnotationInfo that controls both the layout
  --                    mode of the page and which annotations are displayed.
  --                    If omitted, the user's preferred level is obtained from
  --                    AuthenticationController.
  --   applet           optional, a string that controls which visualization
  --                    applet is displayed on the page.  One of 'minijamm',
  --                    'jamm1', 'jamm2', or 'jammed'.  If omitted, the user's
  --                    preferred applet choice is obtained from
  --                    AuthenticationController.  
  --   setLevel         optional, if '1' then the user's preferred level (as
  --                    maintained by AuthenticationController) is set to the
  --                    level specified.  If omitted, then the level specified
  --                    (if any) is assumed to be transient and the user's
  --                    level preference remains unchanged.
  --   setApplet        optional, if '1' then the user's preferred applet (as
  --                    maintained by AuthenticationController) is set to the
  --                    applet specified.  If omitted, then the applet
  --                    specified (if any) is assumed to be transient and the 
  --                    user's applet preference remains unchanged.
  --%>

<%@page session="true" isThreadSafe="true"
        info="Sample Details" 
        import="java.io.PrintWriter"
        import="java.rmi.RemoteException"
        import="java.util.ArrayList"
        import="java.util.Iterator"
        import="java.util.List"
        import="org.recipnet.site.container.RepositoryDirectory"
        import="org.recipnet.site.container.RepositoryFile"
        import="org.recipnet.site.container.SampleAnnotationInfo"
        import="org.recipnet.site.container.SampleDataInfo"
        import="org.recipnet.site.container.SampleHistoryInfo"
        import="org.recipnet.site.container.SampleInfo"
        import="org.recipnet.site.container.SampleTextInfo"
        import="org.recipnet.site.wrapper.HtmlHelper"
  %>

<%--
	Include the common session definitions.
--%>
<%@ include file="/WEB-INF/common.inc" %>

<%
    int sampleId;
    int sampleHistoryId;
    int level;
    String appletChoice;
    int repositoryTicket;
    boolean researcherMode;
    boolean commonMoleculesMode;
    String contextPath = ((HttpServletRequest) request).getContextPath();

    // These variables are used only in common molecules mode
    List compoundNames = null;
    String compoundName = null;

    // Do a quick sanity check
    if (! "GET".equals(request.getMethod())) {
        // GET is the only supported method on this page
        response.sendError(response.SC_METHOD_NOT_ALLOWED);
        return;
    }

    // Retrieve and decode query-line parameters
    try {
        String sampleIdStr = request.getParameter("sampleId");
        if (sampleIdStr != null && sampleIdStr.trim().length() > 0) {
            sampleId = Integer.parseInt(sampleIdStr);
        } else {
            sampleId = SampleInfo.INVALID_SAMPLE_ID;
        }

        String sampleHistoryIdStr = request.getParameter("sampleHistoryId");
        if (sampleHistoryIdStr != null && sampleIdStr.trim().length() > 0) {
            sampleHistoryId = Integer.parseInt(sampleHistoryIdStr);
        } else {
            sampleHistoryId = SampleHistoryInfo.INVALID_SAMPLE_HISTORY_ID;
        }

	String levelStr = request.getParameter("level");
	if (levelStr != null && levelStr.trim().length() > 0) {
            level = Integer.parseInt(levelStr);
        } else {
            level = authController.getPreferredLevel();
        }
	if (level <= SampleAnnotationInfo.GENERIC_COMMONMOLECULES_LEVEL) {
	    researcherMode = false;
            commonMoleculesMode = true;
        } else {
            researcherMode = true;
            commonMoleculesMode = false;
        }

        String appletChoiceStr = request.getParameter("applet");
        if (appletChoiceStr != null && appletChoiceStr.trim().length() > 0) {
            appletChoice = appletChoiceStr.trim().toLowerCase();
        } else {
            appletChoice = authController.getPreferredApplet();
        }
        if (! (appletChoice.equals("minijamm")
               || appletChoice.equals("jamm1")
               || appletChoice.equals("jamm2"))) {
            // The specified applet string is invalid
            response.sendError(response.SC_BAD_REQUEST);
            return;
        }

	String setLevelStr = request.getParameter("setLevel");
        if ("1".equals(setLevelStr)) {
            authController.setPreferredLevel(level);
        }

        String setAppletStr = request.getParameter("setApplet");
        if ("1".equals(setAppletStr)) {
            authController.setPreferredApplet(appletChoice);
        }
    } catch (NumberFormatException ex) {
	response.sendError(response.SC_BAD_REQUEST);
	return;
    }

    // Do a user authorization check and forward to login.jsp if it fails
    if (!authController.canSeeSample(sampleId)) {
	if (!authController.checkUserAuthenticationStatus()) {
            request.setAttribute("reason",
                                 authController.AUTHENTICATION_REQUIRED);
        } else {
            request.setAttribute("reason", authController.INSUFFICIENT_ACCESS);
	} %>
        <jsp:forward page="/login.jsp" /> <%
    }

    // Instruct PageHelper to retrieve the sample metadata and information
    // about the data files from the core.  Obtain a ticket number that can be
    // used to access repository files.
    pageHelper.retrieveSingleSample(sampleId, sampleHistoryId);
    pageHelper.retrieveLocalTrackingConfig();
    pageHelper.retrieveRepositoryDir(sampleId);
    if (pageHelper.getRepositoryDirStatus() ==
            RepositoryDirectory.DATADIR_NOT_NEEDED) {
        // TODO: probably should throw an exception here instead of just
        //       signalling a bad request.  Maybe should even suggest to the
        //       user other sites that *do* host this sample.
	response.sendError(response.SC_BAD_REQUEST,
                "Data for this sample not held on this site");
        return;
    }
    if (pageHelper.getRepositoryDirStatus() == RepositoryDirectory.DATADIR_OK){
        repositoryTicket = pageHelper.grantNewTicket();
    } else {
        repositoryTicket = 0;
    }

    // If we're in common molecules mode, predetermine a few frequently-used
    // values.
    if (commonMoleculesMode) {
        // Build a list of all the "compound names" by which this sample is
        // known.  Trade names, common names, and IUPAC names all qualify.
        String name;
        boolean rc;
        compoundNames = new ArrayList();

        name = pageHelper.getNextAttributeValue(SampleTextInfo.TRADE_NAME);
        while (name != null) {
            compoundNames.add(name);
            name = pageHelper.getNextAttributeValue(SampleTextInfo.TRADE_NAME);
        }

        name = pageHelper.getNextAttributeValue(SampleTextInfo.COMMON_NAME);
        while (name != null) {
            compoundNames.add(name);
            name = pageHelper.getNextAttributeValue(SampleTextInfo.COMMON_NAME);
        }

        while (pageHelper.moveNextSampleAnnotation(SampleTextInfo.IUPAC_NAME)){
            compoundNames.add(pageHelper.getAnnotationValue());
        }

        if (compoundNames.isEmpty()) {
            // No names are available for this sample.  Just make one up.
            name = pageHelper.getSampleLabName() + " #"
                    + pageHelper.getSampleLocalLabId();
            compoundNames.add(name);
        }

        // The first compound name in the list is assumed to be this sample's
        // preferred compound name, used in several places.
        compoundName = (String) compoundNames.get(0);
    }
%>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
          "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
    <title>
      <%= commonMoleculesMode
          ? compoundName + " - Reciprocal Net Common Molecules"
          : pageHelper.getSampleLabShortName() + " #"
            + pageHelper.getSampleLocalLabId() + " - Reciprocal Net" %>
    </title>
    <link href="recipnet.css" rel="stylesheet" type="text/css" />
  </head>
  <body class="<%= commonMoleculesMode
                   ? "showSampleCommonModeBody"
                   : "" %>">
    <%-- TODO: the extra set of parentheses in the parameter value below is
      --       necessary to work around a bug in j2sdk1.4.1.  Remove them
      --       once Sun resolves the bug.
      --%>
    <jsp:include page="/header.jsp">
        <jsp:param name="pageTitle" value=
                "<%= (commonMoleculesMode
                         ? compoundName + " - Reciprocal Net Common Molecule"
                         : pageHelper.getSampleLabShortName() + " #"
                           + pageHelper.getSampleLocalLabId()) %>" />
    </jsp:include>

    <table width="100%">
      <tr valign="top">
        <td rowspan="2" width="400"> <%
          if (repositoryTicket != 0
                    && pageHelper.getUrlForCrtFile(repositoryTicket) != null) {
                   // Display the applet, according to the user's preference
              if (appletChoice.equals("minijamm")) { %>
                  <applet code="org.recipnet.site.jamm.minijamm.miniJaMM.class"
                          codebase="applets/jamm/"
                          archive="miniJaMM.jar"
                          width=400
                          height=400>
                    <param name="background" value="eeeeee" />
	            <param name="textcolor" value="000000" />
		    <param name="border" value="true" />
		    <param name="model"
                            value="<%= pageHelper.getUrlForCrtFile(
                                               repositoryTicket) %>" />
                  </applet> <%
              } else if (appletChoice.equals("jamm1")) { %>
                  <applet code="org.recipnet.site.jamm.jamm1.JaMM.class"
                          codebase="applets/jamm/"
                          archive="JaMM1.jar"
                          width="400"
                          height="400">
		    <param name="model"
                            value="<%= pageHelper.getUrlForCrtFile(
                                               repositoryTicket) %>" />
                    <param name="sampleId" value="<%=sampleId%>" />
                    <param name="ortep"
                           value="<%=contextPath%>/servlet/jammsupport" />
                    <param name="render"
                           value="<%=contextPath%>/servlet/jammsupport" />
                  </applet> <%
              } else if (appletChoice.equals("jamm2")) { %>
                  <object classid="clsid:8AD9C840-044E-11D1-B3E9-00805F499D93"
                          width="400"
                          height="400"
                          codebase="http://java.sun.com/products/plugin/autodl/jinstall-1_4_0-win.cab#Version=1,2,0,0">
                    <param name="code"
                             value="org.recipnet.site.jamm.jamm2.JaMM.class" />
                    <param name="archive" value="applets/jamm/JaMM2.jar" />
                    <param name="type"
                             value="application/x-java-applet;version=1.2" />
                    <param name="model"
                             value="<%= pageHelper.getUrlForCrtFile(
                                                repositoryTicket) %>" />
                    <param name="sampleId" value="<%=sampleId%>" />
                    <param name="help" value="applets/jamm/JaMM.help" />
                    <param name="line"
                           value="<%=contextPath%>/servlet/jammsupport" />
                    <param name="ortep"
                           value="<%=contextPath%>/servlet/jammsupport" />
                    <param name="render"
                           value="<%=contextPath%>/servlet/jammsupport" />
                    <param name="color" value="0x9F9F9F" />
                    <comment>
                      <embed
                            type="application/x-java-applet;version=1.2"
                            java_code="org.recipnet.site.jamm.jamm2.JaMM.class"
                            java_archive="applets/jamm/JaMM2.jar"
                            width="400"
                            height="400"
                            model="<%= pageHelper.getUrlForCrtFile(
                                               repositoryTicket) %>"
                            sampleId="<%=sampleId%>"
                            help="applets/jamm/JaMM.help"
                            line="<%=contextPath%>/servlet/jammsupport"
                            ortep="<%=contextPath%>/servlet/jammsupport"
                            render="<%=contextPath%>/servlet/jammsupport"
                            pluginspage="http://java.sun.com/products/plugin/1.2/plugin-install.html"
                            color="0x9F9F9F"
                        />
                    </comment>
                  </object> <%
              }
              if (commonMoleculesMode) { %>
                  <table cellspacing="0" cellpadding="0" border="0">
                    <tr>
                      <td valign="top">
                        <img src="images/tip.gif" />
                      </td>
                      <td valign="top">
                        <span class="showSampleTipText">
                          Click and drag your mouse inside the applet above to
                          rotate the molecule in 3-D.&nbsp;&nbsp;&nbsp;
                          <a href="help/applets.html" target="_blank"
                                  >Applet instructions...</a>
                        </span>
                      </td>
                    </tr>
                  </table> <%
              } %>
	      <p class="showSampleTipText">
                Switch to another visualization applet:
                <table cellspacing="0" cellpadding="0" border="0">
                  <%= getHtmlForAppletSelectionRow(sampleId, sampleHistoryId,
                              level, "minijamm", "miniJaMM", "miniJaMM",
                              appletChoice.equals("minijamm")) %>
                  <%= getHtmlForAppletSelectionRow(sampleId, sampleHistoryId,
                              level, "jamm1", "JaMM 1", "JaMM1",
                              appletChoice.equals("jamm1")) %>
                  <%= getHtmlForAppletSelectionRow(sampleId, sampleHistoryId,
                              level, "jamm2", "JaMM 2", "JaMM2",
                              appletChoice.equals("jamm2")) %>
                </table>
              </p><%
          } else {
              out.println("&nbsp;");
          } %>
        </td>
	    <td width="24">&nbsp;</td>
        <td> <%
          if (commonMoleculesMode) {
              // Display a header line with the compound's name, formula,
              // and short description. %>
              <p align="center">
                <span class="showSampleBannerFirstLine">
                  <%= compoundName %>
                </span>
                <br />
                <span class="showSampleBannerSecondLine">
                  <%= HtmlHelper.nullToBlank(
                              pageHelper.getNextAttributeValue(
                                      SampleTextInfo.SHORT_DESCRIPTION)) %>
                </span>
                <br />&nbsp;<br />
              </p> <%
              String chemicalFormula =
                      pageHelper.getSamplePreferredFormula(level);
              if (chemicalFormula != null) {
	          out.println("<p><span"
                              + " class=\"showSampleCommonModeLabelFont\">"
                              + "Chemical Formula: </span>"
                              + "<span"
			      + " class=\"showSampleCommonModeDataFont\">"
		              + HtmlHelper.prettyHtmlChemicalFormula(
                                      chemicalFormula)
			      + "</span></p>");
              }

              // Display other known names of the sample if there are any
              StringBuffer names = new StringBuffer();
              boolean isFirstName = true;
              Iterator it = compoundNames.iterator();
              it.next();  // discard the first element
              while (it.hasNext()) {
                  if (isFirstName) {
                      isFirstName = false;
                  } else {
                      names.append(", ");
                  }
                  names.append((String) it.next());
              }
	      if (names.length() > 0) {
	          out.println("<p><span"
                              + " class=\"showSampleCommonModeLabelFont\">"
                              + "Other names: </span>"
                              + "<span"
			      + " class=\"showSampleCommonModeDataFont\">"
		              + names.toString()
			      + "</span></p>");
              }

	      // Display every available layman's explanation
              boolean rc;
              rc = pageHelper.moveNextSampleAnnotation(
                      SampleTextInfo.LAYMANS_EXPLANATION);
              while (rc) {
                  if ((pageHelper.getAnnotationLevel() & level) != 0
                          || pageHelper.getAnnotationLevel()
                                  == SampleAnnotationInfo.ALL_LEVELS) {
	              out.println("<p><span"
                                  + " class=\"showSampleCommonModeLabelFont\">"
                                  + "Explanation: </span>"
                                  + "<span"
			          + " class=\"showSampleCommonModeDataFont\">"
		                  + pageHelper.getAnnotationValue()
			          + "</span></p>");
                  }
                  rc = pageHelper.moveNextSampleAnnotation(
                          SampleTextInfo.LAYMANS_EXPLANATION);
              }

              // Display a single list of keywords if there are any
	      StringBuffer keywords = new StringBuffer();
              boolean isFirstKeyword = true;
              String keyword = pageHelper.getNextAttributeValue(
                      SampleTextInfo.KEYWORD);
              while (keyword != null) {
                  if (isFirstKeyword) {
                      isFirstKeyword = false;
                  } else {
                      keywords.append(", ");
                  }
                  keywords.append(keyword);
		  keyword = pageHelper.getNextAttributeValue(
                          SampleTextInfo.KEYWORD);
              }
	      if (keywords.length() > 0) {
	          out.println("<p><span"
                              + " class=\"showSampleCommonModeLabelFont\">"
                              + "Keywords: </span>"
                              + "<span"
			      + " class=\"showSampleCommonModeDataFont\">"
		              + keywords.toString()
			      + "</span></p>");
              }
          }

          if (researcherMode) {
              out.println("<table class=\"dataTable\" cellSpacing=\"0\">");

              // Display the chemical formula(e) if available
              String empiricalFormula = pageHelper.getNextAttributeValue(
                      SampleTextInfo.EMPIRICAL_FORMULA);
              while (empiricalFormula != null) {
                  out.println(displayOneItem(HtmlHelper.textTypeStr(
                          SampleTextInfo.EMPIRICAL_FORMULA, null),
                          HtmlHelper.prettyHtmlChemicalFormula(
                                  empiricalFormula)));
                  empiricalFormula = pageHelper.getNextAttributeValue(
                          SampleTextInfo.EMPIRICAL_FORMULA);
              }

              // Display every data value available
              out.println(displayOneItem("a",
                      pageHelper.getSampleA(), 4, "&#197;"));
              out.println(displayOneItem("b",
                      pageHelper.getSampleB(), 4, "&#197;"));
              out.println(displayOneItem("c",
                      pageHelper.getSampleC(), 4, "&#197;"));
              out.println(displayOneItem("alpha",
                      pageHelper.getSampleAlpha(), 2, "&#176;"));
              out.println(displayOneItem("beta",
                      pageHelper.getSampleBeta(), 2, "&#176;"));
              out.println(displayOneItem("gamma",
                      pageHelper.getSampleGamma(), 2, "&#176;"));
              out.println(displayOneItem("space group",
                      pageHelper.getSampleSpaceGroup()));
              out.println(displayOneItem("calculated density",
                      pageHelper.getSampleCalculatedDensity(), 3,
                      "g/cm<sup>3</sup>"));
              out.println(displayOneItem("color",
                      pageHelper.getSampleColor()));
              out.println(displayOneItem("z", pageHelper.getSampleZ()));
              out.println(displayOneItem("temperature",
                      pageHelper.getSampleT(), 1, "&#176;C"));
              out.println(displayOneItem("volume",
                      pageHelper.getSampleV(), 3, "&#197;<sup>3</sup>"));
              out.println(displayOneItem("formula weight",
                      pageHelper.getFormulaWeight(), 3, "g/mole"));
              out.println(displayOneItem("R(F)",
                      pageHelper.getSampleRf(), 3, null));
              out.println(displayOneItem("R<sub>w</sub>(F)",
                      pageHelper.getSampleRwf(), 3, null));
              out.println(displayOneItem("R(F<sup>2</sup>)",
                      pageHelper.getSampleRf2(), 3, null));
              out.println(displayOneItem("R<sub>w</sub>(F<sup>2</sup>)",
                      pageHelper.getSampleRwf2(), 3, null));
              out.println(displayOneItem("goodness of fit",
                      pageHelper.getSampleGoof(), 3, null));
              out.println(displayOneItem("Summary",
                      pageHelper.getSampleSummary()));

              // Display every attribute available
              String attributeValue = pageHelper.getNextAttributeValue(
                      SampleTextInfo.INVALID_TYPE);
              while (attributeValue != null) {
	          if (pageHelper.getCurrentAttributeType()
                              == SampleTextInfo.EMPIRICAL_FORMULA
                          || ! authController.canSeeSampleText(sampleId,
                                  pageHelper.getCurrentAttributeType())) {
                      // Don't display the current attribute.  Either we've
                      // already displayed the same information elsewhere on
                      // page, or the user is not authorized to see this
                      // attribute.
                  } else {
                      // Special handling for moiety formula and structural
	    	      // formula
                      if (pageHelper.getCurrentAttributeType()
                               == SampleTextInfo.MOIETY_FORMULA
	    		    || pageHelper.getCurrentAttributeType()
                               == SampleTextInfo.STRUCTURAL_FORMULA
                            ||  pageHelper.getCurrentAttributeType()
                               == SampleTextInfo.EMPIRICAL_FORMULA_DERIVED
                            || pageHelper.getCurrentAttributeType()
                               == SampleTextInfo.EMPIRICAL_FORMULA_SINGLE_ION
                            || pageHelper.getCurrentAttributeType()
                               == SampleTextInfo.EMPIRICAL_FORMULA_LESS_SOLVENT
                              ) {
                          out.println(displayOneItem(
                                  pageHelper.getCurrentAttributeTypeStr(),
                                  HtmlHelper.prettyHtmlChemicalFormula(
                                          attributeValue)));
  		      } else {
                          out.println(displayOneItem(
                                  pageHelper.getCurrentAttributeTypeStr(),
                                  attributeValue));
                      }
                  }
 	          attributeValue = pageHelper.getNextAttributeValue(
                          SampleTextInfo.INVALID_TYPE);
              }

	      // Display every annotation available
              while(pageHelper.moveNextSampleAnnotation(
                      SampleTextInfo.INVALID_TYPE)) {
                  if (! authController.canSeeSampleText(sampleId,
                          pageHelper.getCurrentAnnotationType())) {
                      // The user is not authorized to see this annotation.
                      continue;
                  }

		  out.println(displayOneItem(
                          pageHelper.getCurrentAnnotationTypeStr(),
                          pageHelper.getAnnotationValue()));
              }

	      // Display the lab name and provider name
              out.println(displayOneItem("Lab",
                      pageHelper.getSampleLabName()));
              out.println(displayOneItem("Provider",
                      pageHelper.getSampleProviderName()));

	      out.println("</table>");
            } %>
        </td>
      </tr>
      <tr>
        <td colspan="2" align="right" valign="bottom"> <%
          if (researcherMode) {
	      // Display a link to "common molecules mode" %>
              <a href="<%= getThisPageUrl(sampleId, sampleHistoryId,
                            SampleAnnotationInfo.GENERIC_COMMONMOLECULES_LEVEL,
                            appletChoice, true, false) %>"
              >Basic view...</a><br /> <%
          }
	  if (commonMoleculesMode) {
	      // Display a link to "researcher mode" %>
              <a href="<%= getThisPageUrl(sampleId, sampleHistoryId,
                                   SampleAnnotationInfo.RESEARCHER_LEVEL,
                                   appletChoice, true, false) %>"
              >Crystallographic details...</a><br /> <%
          } %>
          <a href="jamm.jsp?sampleId=<%=sampleId%>"
                  >More visualization options...<a><br> <%
          if (authController.canEditSample(sampleId)) {
              // Display a link to the lab/sample.jsp page
              String editPageUrl = "lab/sample.jsp?sampleId=" + sampleId;
              if (sampleHistoryId
                      != SampleHistoryInfo.INVALID_SAMPLE_HISTORY_ID) {
                  editPageUrl += "&sampleHistoryId=" + sampleHistoryId;
              } %>
 	      <a href="<%= editPageUrl %>">Edit this sample...</a><br /> <%
          } %>
        </td>
      </tr>
    </table>
    <br />
    <%
    if (repositoryTicket != 0 && researcherMode) { %>
	<hr />
	Repository Files:
	<br />
	<table width="100%">
	  <tr> <%
	    String repositoryDirBaseUrl;
            Iterator iterator =pageHelper.getRepositoryDirFiles().iterator();
            repositoryDirBaseUrl = pageHelper.getRepositoryDirUrl();
	    int i;
            int j = 0;

            while (iterator.hasNext()) {
                String fileName = ((RepositoryFile) iterator.next()).name;
		if (j == 5) {
                    j = 0;
                    out.println("</tr><tr>");
                }

                out.println("<td><a href=\"" + repositoryDirBaseUrl
                            + fileName + "?ticket=" + repositoryTicket
                            + "\">" + fileName + "</a></td>");
		j++;
            } %>
	  </tr>
	</table> <%
    } else if (researcherMode) { %>
	<font color="red" size="+1">
	  No files for <%=pageHelper.getSampleLocalLabId()%> in repository!
	  <br />
        </font> <%
    } %>
    <jsp:include page="/footer.jsp" />
  </body>
</html>
<%!
    /**
     * Returns an HTML-formatted string that can comprise one line of the data
     * table.  An empty string is returned if dvalue is INVALID_DOUBLE_VALUE.
     * @param title is the field title
     * @param dvalue is the value to display (type double)
     * @param decimalSize is the number of digits of precision to display after
     *     the decimal point.
     * @param unit is an HTML-coded string that describes the measurement unit
     *     for this field, or null if nothing should be displayed
     */
    String displayOneItem(String title, double dvalue, int decimalSize,
	    String unit) {
        if (Double.compare(dvalue, SampleDataInfo.INVALID_DOUBLE_VALUE) == 0) {
            return "";
        }
        return "<tr><td class=\"dataTableLabelCell\">"
                + "<span class=\"dataTableLabelFont\">"
		+ title + ": " + "</span></td>"
	        + "<td class=\"dataTableDataCell\">"
		+ "<span class=\"dataTableDataFont\">"
		+ HtmlHelper.doubleToString(dvalue, decimalSize)
	        + "</span> <span class=\"dataTableUnitFont\">"
                + HtmlHelper.nullToBlank(unit)
                + "</span></td></tr>";
    }

    /**
     * Returns an HTML-formatted string that can comprise one line of the data
     * table.  An empty string is returned if dvalue is INVALID_INT_VALUE.
     * @param title is the field title
     * @param ivalue is the value to display (type int)
     */
    String displayOneItem(String title, int ivalue) {
        if (ivalue == SampleDataInfo.INVALID_INT_VALUE) {
            return "";
        }
        return "<tr><td class=\"dataTableLabelCell\">"
                + "<span class=\"dataTableLabelFont\">"
		+ title + ": " + "</span></td>"
	        + "<td class=\"dataTableDataCell\">"
		+ "<span class=\"dataTableDataFont\">"
		+ ivalue
               + "</span></td></tr>";
    }

    /**
     * Returns an HTML-formatted string that can comprise one line of the data
     * table.  An empty string is returned if svalue is null or empty.
     * @param title is the field title
     * @param svalue is the value to display (type String)
     */
    String displayOneItem(String title, String svalue) {
        if (svalue == null || svalue.length() == 0) {
	    return "";
        }
        return "<tr><td class=\"dataTableLabelCell\">"
                + "<span class=\"dataTableLabelFont\">"
		+ title + ": " + "</span></td>"
	        + "<td class=\"dataTableDataCell\">"
		+ "<span class=\"dataTableDataFont\">"
		+ svalue
               + "</span></td></tr>";
    }

    /**
     * Returns a partial URL (URL path) to this page, which will be rendered
     * with the specified parameters.
     */
    String getThisPageUrl(int sampleId, int sampleHistoryId, int level,
                          String appletChoice, boolean setLevel,
                          boolean setApplet) {
        return "showsample.jsp?sampleId=" + sampleId
                + "&sampleHistoryId=" + sampleHistoryId
                + "&level=" + level
                + "&applet=" + appletChoice
                + (setLevel ? "&setLevel=1" : "")
                + (setApplet ? "&setApplet=1" : "");
    }

    String getHtmlForAppletSelectionRow(int sampleId, int sampleHistoryId,
                                        int level, String appletChoice,
                                        String displayName,
                                        String jammPageApplet,
                                        boolean selected) {
        StringBuffer buf = new StringBuffer();

        buf.append("<tr><td><img src=\"");
        if (selected) {
            buf.append("images/pointer.gif");
        } else {
            buf.append("images/pointer-blank.gif");
        }
        buf.append("\" /></td><td>");

        if (! selected) {
            buf.append("<a href=\"");
            buf.append(getThisPageUrl(sampleId, sampleHistoryId, level,
                    appletChoice, false, true));
            buf.append("\">");
        }

        if (selected) {
            buf.append("<strong>");
        }
        buf.append(displayName);
        if (selected) {
            buf.append("</strong>");
        }
        if (!selected) {
            buf.append("</a>");
        }
        buf.append("</td><td width=\"20\">&nbsp;</td><td>");
        if (selected) {
            buf.append("<a href=\"jamm.jsp?sampleId=");
            buf.append(sampleId);
            buf.append("&jamm=");
            buf.append(jammPageApplet);
            buf.append("\" target=\"_blank\">");
            buf.append("open in new window...");
            buf.append("</a>");
        }
        buf.append("</td></tr>");

	return buf.toString();
    }
%>
